### Available types

All types used in the Bot API responses are represented as JSON-objects.

It is safe to use 32-bit signed integers for storing all Integer fields unless otherwise noted.

> Optional fields may be not returned when irrelevant.

#### User

This object represents a Telegram user or bot.

Field | Type | Description
--- | --- | ---
id | Integer | Unique identifier for this user or bot. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier.
is_bot | Boolean | True, if this user is a bot
first_name | String | User's or bot's first name
last_name | String | Optional. User's or bot's last name
username | String | Optional. User's or bot's username
language_code | String | Optional. IETF language tag of the user's language
is_premium | True | Optional. True, if this user is a Telegram Premium user
added_to_attachment_menu | True | Optional. True, if this user added the bot to the attachment menu
can_join_groups | Boolean | Optional. True, if the bot can be invited to groups. Returned only in getMe.
can_read_all_group_messages | Boolean | Optional. True, if privacy mode is disabled for the bot. Returned only in getMe.
supports_inline_queries | Boolean | Optional. True, if the bot supports inline queries. Returned only in getMe.
can_connect_to_business | Boolean | Optional. True, if the bot can be connected to a Telegram Business account to receive its messages. Returned only in getMe.
has_main_web_app | Boolean | Optional. True, if the bot has a main Web App. Returned only in getMe.
has_topics_enabled | Boolean | Optional. True, if the bot has forum topic mode enabled in private chats. Returned only in getMe.
allows_users_to_create_topics | Boolean | Optional. True, if the bot allows users to create and delete topics in private chats. Returned only in getMe.

#### Chat

This object represents a chat.

Field | Type | Description
--- | --- | ---
id | Integer | Unique identifier for this chat. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier.
type | String | Type of the chat, can be either “private”, “group”, “supergroup” or “channel”
title | String | Optional. Title, for supergroups, channels and group chats
username | String | Optional. Username, for private chats, supergroups and channels if available
first_name | String | Optional. First name of the other party in a private chat
last_name | String | Optional. Last name of the other party in a private chat
is_forum | True | Optional. True, if the supergroup chat is a forum (has topics enabled)
is_direct_messages | True | Optional. True, if the chat is the direct messages chat of a channel

#### ChatFullInfo

This object contains full information about a chat.

Field | Type | Description
--- | --- | ---
id | Integer | Unique identifier for this chat. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier.
type | String | Type of the chat, can be either “private”, “group”, “supergroup” or “channel”
title | String | Optional. Title, for supergroups, channels and group chats
username | String | Optional. Username, for private chats, supergroups and channels if available
first_name | String | Optional. First name of the other party in a private chat
last_name | String | Optional. Last name of the other party in a private chat
is_forum | True | Optional. True, if the supergroup chat is a forum (has topics enabled)
is_direct_messages | True | Optional. True, if the chat is the direct messages chat of a channel
accent_color_id | Integer | Identifier of the accent color for the chat name and backgrounds of the chat photo, reply header, and link preview. See accent colors for more details.
max_reaction_count | Integer | The maximum number of reactions that can be set on a message in the chat
photo | ChatPhoto | Optional. Chat photo
active_usernames | Array of String | Optional. If non-empty, the list of all active chat usernames; for private chats, supergroups and channels
birthdate | Birthdate | Optional. For private chats, the date of birth of the user
business_intro | BusinessIntro | Optional. For private chats with business accounts, the intro of the business
business_location | BusinessLocation | Optional. For private chats with business accounts, the location of the business
business_opening_hours | BusinessOpeningHours | Optional. For private chats with business accounts, the opening hours of the business
personal_chat | Chat | Optional. For private chats, the personal channel of the user
parent_chat | Chat | Optional. Information about the corresponding channel chat; for direct messages chats only
available_reactions | Array of ReactionType | Optional. List of available reactions allowed in the chat. If omitted, then all emoji reactions are allowed.
background_custom_emoji_id | String | Optional. Custom emoji identifier of the emoji chosen by the chat for the reply header and link preview background
profile_accent_color_id | Integer | Optional. Identifier of the accent color for the chat's profile background. See profile accent colors for more details.
profile_background_custom_emoji_id | String | Optional. Custom emoji identifier of the emoji chosen by the chat for its profile background
emoji_status_custom_emoji_id | String | Optional. Custom emoji identifier of the emoji status of the chat or the other party in a private chat
emoji_status_expiration_date | Integer | Optional. Expiration date of the emoji status of the chat or the other party in a private chat, in Unix time, if any
bio | String | Optional. Bio of the other party in a private chat
has_private_forwards | True | Optional. True, if privacy settings of the other party in the private chat allows to use `tg://user?id=<user_id>` links only in chats with the user
has_restricted_voice_and_video_messages | True | Optional. True, if the privacy settings of the other party restrict sending voice and video note messages in the private chat
join_to_send_messages | True | Optional. True, if users need to join the supergroup before they can send messages
join_by_request | True | Optional. True, if all users directly joining the supergroup without using an invite link need to be approved by supergroup administrators
description | String | Optional. Description, for groups, supergroups and channel chats
invite_link | String | Optional. Primary invite link, for groups, supergroups and channel chats
pinned_message | Message | Optional. The most recent pinned message (by sending date)
permissions | ChatPermissions | Optional. Default chat member permissions, for groups and supergroups
accepted_gift_types | AcceptedGiftTypes | Information about types of gifts that are accepted by the chat or by the corresponding user for private chats
can_send_paid_media | True | Optional. True, if paid media messages can be sent or forwarded to the channel chat. The field is available only for channel chats.
slow_mode_delay | Integer | Optional. For supergroups, the minimum allowed delay between consecutive messages sent by each unprivileged user; in seconds
unrestrict_boost_count | Integer | Optional. For supergroups, the minimum number of boosts that a non-administrator user needs to add in order to ignore slow mode and chat permissions
message_auto_delete_time | Integer | Optional. The time after which all messages sent to the chat will be automatically deleted; in seconds
has_aggressive_anti_spam_enabled | True | Optional. True, if aggressive anti-spam checks are enabled in the supergroup. The field is only available to chat administrators.
has_hidden_members | True | Optional. True, if non-administrators can only get the list of bots and administrators in the chat
has_protected_content | True | Optional. True, if messages from the chat can't be forwarded to other chats
has_visible_history | True | Optional. True, if new chat members will have access to old messages; available only to chat administrators
sticker_set_name | String | Optional. For supergroups, name of the group sticker set
can_set_sticker_set | True | Optional. True, if the bot can change the group sticker set
custom_emoji_sticker_set_name | String | Optional. For supergroups, the name of the group's custom emoji sticker set. Custom emoji from this set can be used by all users and bots in the group.
linked_chat_id | Integer | Optional. Unique identifier for the linked chat, i.e. the discussion group identifier for a channel and vice versa; for supergroups and channel chats. This identifier may be greater than 32 bits and some programming languages may have difficulty/silent defects in interpreting it. But it is smaller than 52 bits, so a signed 64 bit integer or double-precision float type are safe for storing this identifier.
location | ChatLocation | Optional. For supergroups, the location to which the supergroup is connected
rating | UserRating | Optional. For private chats, the rating of the user if any
first_profile_audio | Audio | Optional. For private chats, the first audio added to the profile of the user
unique_gift_colors | UniqueGiftColors | Optional. The color scheme based on a unique gift that must be used for the chat's name, message replies and link previews
paid_message_star_count | Integer | Optional. The number of Telegram Stars a general user have to pay to send a message to the chat

#### Message

This object represents a message.

Field | Type | Description
--- | --- | ---
message_id | Integer | Unique message identifier inside this chat. In specific instances (e.g., message containing a video sent to a big chat), the server might automatically schedule a message instead of sending it immediately. In such cases, this field will be 0 and the relevant message will be unusable until it is actually sent
message_thread_id | Integer | Optional. Unique identifier of a message thread or forum topic to which the message belongs; for supergroups and private chats only
direct_messages_topic | DirectMessagesTopic | Optional. Information about the direct messages chat topic that contains the message
from | User | Optional. Sender of the message; may be empty for messages sent to channels. For backward compatibility, if the message was sent on behalf of a chat, the field contains a fake sender user in non-channel chats
sender_chat | Chat | Optional. Sender of the message when sent on behalf of a chat. For example, the supergroup itself for messages sent by its anonymous administrators or a linked channel for messages automatically forwarded to the channel's discussion group. For backward compatibility, if the message was sent on behalf of a chat, the field from contains a fake sender user in non-channel chats.
sender_boost_count | Integer | Optional. If the sender of the message boosted the chat, the number of boosts added by the user
sender_business_bot | User | Optional. The bot that actually sent the message on behalf of the business account. Available only for outgoing messages sent on behalf of the connected business account.
sender_tag | String | Optional. Tag or custom title of the sender of the message; for supergroups only
date | Integer | Date the message was sent in Unix time. It is always a positive number, representing a valid date.
business_connection_id | String | Optional. Unique identifier of the business connection from which the message was received. If non-empty, the message belongs to a chat of the corresponding business account that is independent from any potential bot chat which might share the same identifier.
chat | Chat | Chat the message belongs to
forward_origin | MessageOrigin | Optional. Information about the original message for forwarded messages
is_topic_message | True | Optional. True, if the message is sent to a topic in a forum supergroup or a private chat with the bot
is_automatic_forward | True | Optional. True, if the message is a channel post that was automatically forwarded to the connected discussion group
reply_to_message | Message | Optional. For replies in the same chat and message thread, the original message. Note that the Message object in this field will not contain further reply_to_message fields even if it itself is a reply.
external_reply | ExternalReplyInfo | Optional. Information about the message that is being replied to, which may come from another chat or forum topic
quote | TextQuote | Optional. For replies that quote part of the original message, the quoted part of the message
reply_to_story | Story | Optional. For replies to a story, the original story
reply_to_checklist_task_id | Integer | Optional. Identifier of the specific checklist task that is being replied to
via_bot | User | Optional. Bot through which the message was sent
edit_date | Integer | Optional. Date the message was last edited in Unix time
has_protected_content | True | Optional. True, if the message can't be forwarded
is_from_offline | True | Optional. True, if the message was sent by an implicit action, for example, as an away or a greeting business message, or as a scheduled message
is_paid_post | True | Optional. True, if the message is a paid post. Note that such posts must not be deleted for 24 hours to receive the payment and can't be edited.
media_group_id | String | Optional. The unique identifier inside this chat of a media message group this message belongs to
author_signature | String | Optional. Signature of the post author for messages in channels, or the custom title of an anonymous group administrator
paid_star_count | Integer | Optional. The number of Telegram Stars that were paid by the sender of the message to send it
text | String | Optional. For text messages, the actual UTF-8 text of the message
entities | Array of MessageEntity | Optional. For text messages, special entities like usernames, URLs, bot commands, etc. that appear in the text
link_preview_options | LinkPreviewOptions | Optional. Options used for link preview generation for the message, if it is a text message and link preview options were changed
suggested_post_info | SuggestedPostInfo | Optional. Information about suggested post parameters if the message is a suggested post in a channel direct messages chat. If the message is an approved or declined suggested post, then it can't be edited.
effect_id | String | Optional. Unique identifier of the message effect added to the message
animation | Animation | Optional. Message is an animation, information about the animation. For backward compatibility, when this field is set, the document field will also be set
audio | Audio | Optional. Message is an audio file, information about the file
document | Document | Optional. Message is a general file, information about the file
paid_media | PaidMediaInfo | Optional. Message contains paid media; information about the paid media
photo | Array of PhotoSize | Optional. Message is a photo, available sizes of the photo
sticker | Sticker | Optional. Message is a sticker, information about the sticker
story | Story | Optional. Message is a forwarded story
video | Video | Optional. Message is a video, information about the video
video_note | VideoNote | Optional. Message is a video note, information about the video message
voice | Voice | Optional. Message is a voice message, information about the file
caption | String | Optional. Caption for the animation, audio, document, paid media, photo, video or voice
caption_entities | Array of MessageEntity | Optional. For messages with a caption, special entities like usernames, URLs, bot commands, etc. that appear in the caption
show_caption_above_media | True | Optional. True, if the caption must be shown above the message media
has_media_spoiler | True | Optional. True, if the message media is covered by a spoiler animation
checklist | Checklist | Optional. Message is a checklist
contact | Contact | Optional. Message is a shared contact, information about the contact
dice | Dice | Optional. Message is a dice with random value
game | Game | Optional. Message is a game, information about the game. More about games »
poll | Poll | Optional. Message is a native poll, information about the poll
venue | Venue | Optional. Message is a venue, information about the venue. For backward compatibility, when this field is set, the location field will also be set
location | Location | Optional. Message is a shared location, information about the location
new_chat_members | Array of User | Optional. New members that were added to the group or supergroup and information about them (the bot itself may be one of these members)
left_chat_member | User | Optional. A member was removed from the group, information about them (this member may be the bot itself)
chat_owner_left | ChatOwnerLeft | Optional. Service message: chat owner has left
chat_owner_changed | ChatOwnerChanged | Optional. Service message: chat owner has changed
new_chat_title | String | Optional. A chat title was changed to this value
new_chat_photo | Array of PhotoSize | Optional. A chat photo was change to this value
delete_chat_photo | True | Optional. Service message: the chat photo was deleted
group_chat_created | True | Optional. Service message: the group has been created
supergroup_chat_created | True | Optional. Service message: the supergroup has been created. This field can't be received in a message coming through updates, because bot can't be a member of a supergroup when it is created. It can only be found in reply_to_message if someone replies to a very first message in a directly created supergroup.
channel_chat_created | True | Optional. Service message: the channel has been created. This field can't be received in a message coming through updates, because bot can't be a member of a channel when it is created. It can only be found in reply_to_message if someone replies to a very first message in a channel.
message_auto_delete_timer_changed | MessageAutoDeleteTimerChanged | Optional. Service message: auto-delete timer settings changed in the chat
migrate_to_chat_id | Integer | Optional. The group has been migrated to a supergroup with the specified identifier. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier.
migrate_from_chat_id | Integer | Optional. The supergroup has been migrated from a group with the specified identifier. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier.
pinned_message | MaybeInaccessibleMessage | Optional. Specified message was pinned. Note that the Message object in this field will not contain further reply_to_message fields even if it itself is a reply.
invoice | Invoice | Optional. Message is an invoice for a payment, information about the invoice. More about payments »
successful_payment | SuccessfulPayment | Optional. Message is a service message about a successful payment, information about the payment. More about payments »
refunded_payment | RefundedPayment | Optional. Message is a service message about a refunded payment, information about the payment. More about payments »
users_shared | UsersShared | Optional. Service message: users were shared with the bot
chat_shared | ChatShared | Optional. Service message: a chat was shared with the bot
gift | GiftInfo | Optional. Service message: a regular gift was sent or received
unique_gift | UniqueGiftInfo | Optional. Service message: a unique gift was sent or received
gift_upgrade_sent | GiftInfo | Optional. Service message: upgrade of a gift was purchased after the gift was sent
connected_website | String | Optional. The domain name of the website on which the user has logged in. More about Telegram Login »
write_access_allowed | WriteAccessAllowed | Optional. Service message: the user allowed the bot to write messages after adding it to the attachment or side menu, launching a Web App from a link, or accepting an explicit request from a Web App sent by the method requestWriteAccess
passport_data | PassportData | Optional. Telegram Passport data
proximity_alert_triggered | ProximityAlertTriggered | Optional. Service message. A user in the chat triggered another user's proximity alert while sharing Live Location.
boost_added | ChatBoostAdded | Optional. Service message: user boosted the chat
chat_background_set | ChatBackground | Optional. Service message: chat background set
checklist_tasks_done | ChecklistTasksDone | Optional. Service message: some tasks in a checklist were marked as done or not done
checklist_tasks_added | ChecklistTasksAdded | Optional. Service message: tasks were added to a checklist
direct_message_price_changed | DirectMessagePriceChanged | Optional. Service message: the price for paid messages in the corresponding direct messages chat of a channel has changed
forum_topic_created | ForumTopicCreated | Optional. Service message: forum topic created
forum_topic_edited | ForumTopicEdited | Optional. Service message: forum topic edited
forum_topic_closed | ForumTopicClosed | Optional. Service message: forum topic closed
forum_topic_reopened | ForumTopicReopened | Optional. Service message: forum topic reopened
general_forum_topic_hidden | GeneralForumTopicHidden | Optional. Service message: the 'General' forum topic hidden
general_forum_topic_unhidden | GeneralForumTopicUnhidden | Optional. Service message: the 'General' forum topic unhidden
giveaway_created | GiveawayCreated | Optional. Service message: a scheduled giveaway was created
giveaway | Giveaway | Optional. The message is a scheduled giveaway message
giveaway_winners | GiveawayWinners | Optional. A giveaway with public winners was completed
giveaway_completed | GiveawayCompleted | Optional. Service message: a giveaway without public winners was completed
paid_message_price_changed | PaidMessagePriceChanged | Optional. Service message: the price for paid messages has changed in the chat
suggested_post_approved | SuggestedPostApproved | Optional. Service message: a suggested post was approved
suggested_post_approval_failed | SuggestedPostApprovalFailed | Optional. Service message: approval of a suggested post has failed
suggested_post_declined | SuggestedPostDeclined | Optional. Service message: a suggested post was declined
suggested_post_paid | SuggestedPostPaid | Optional. Service message: payment for a suggested post was received
suggested_post_refunded | SuggestedPostRefunded | Optional. Service message: payment for a suggested post was refunded
video_chat_scheduled | VideoChatScheduled | Optional. Service message: video chat scheduled
video_chat_started | VideoChatStarted | Optional. Service message: video chat started
video_chat_ended | VideoChatEnded | Optional. Service message: video chat ended
video_chat_participants_invited | VideoChatParticipantsInvited | Optional. Service message: new participants invited to a video chat
web_app_data | WebAppData | Optional. Service message: data sent by a Web App
reply_markup | InlineKeyboardMarkup | Optional. Inline keyboard attached to the message. `login_url` buttons are represented as ordinary `url` buttons.

#### MessageId

This object represents a unique message identifier.

Field | Type | Description
--- | --- | ---
message_id | Integer | Unique message identifier. In specific instances (e.g., message containing a video sent to a big chat), the server might automatically schedule a message instead of sending it immediately. In such cases, this field will be 0 and the relevant message will be unusable until it is actually sent

#### InaccessibleMessage

This object describes a message that was deleted or is otherwise inaccessible to the bot.

Field | Type | Description
--- | --- | ---
chat | Chat | Chat the message belonged to
message_id | Integer | Unique message identifier inside the chat
date | Integer | Always 0. The field can be used to differentiate regular and inaccessible messages.

#### MaybeInaccessibleMessage

This object describes a message that can be inaccessible to the bot. It can be one of

- Message
- InaccessibleMessage

#### MessageEntity

This object represents one special entity in a text message. For example, hashtags, usernames, URLs, etc.

Field | Type | Description
--- | --- | ---
type | String | Type of the entity. Currently, can be “mention” (`@username`), “hashtag” (`#hashtag` or `#hashtag@chatusername`), “cashtag” (`$USD` or `$USD@chatusername`), “bot_command” (`/start@jobs_bot`), “url” (`https://telegram.org`), “email” (`do-not-reply@telegram.org`), “phone_number” (`+1-212-555-0123`), “bold” (bold text), “italic” (italic text), “underline” (underlined text), “strikethrough” (strikethrough text), “spoiler” (spoiler message), “blockquote” (block quotation), “expandable_blockquote” (collapsed-by-default block quotation), “code” (monowidth string), “pre” (monowidth block), “text_link” (for clickable text URLs), “text_mention” (for users without usernames), “custom_emoji” (for inline custom emoji stickers), or “date_time” (for formatted date and time)
offset | Integer | Offset in UTF-16 code units to the start of the entity
length | Integer | Length of the entity in UTF-16 code units
url | String | Optional. For “text_link” only, URL that will be opened after user taps on the text
user | User | Optional. For “text_mention” only, the mentioned user
language | String | Optional. For “pre” only, the programming language of the entity text
custom_emoji_id | String | Optional. For “custom_emoji” only, unique identifier of the custom emoji. Use getCustomEmojiStickers to get full information about the sticker
unix_time | Integer | Optional. For “date_time” only, the Unix time associated with the entity
date_time_format | String | Optional. For “date_time” only, the string that defines the formatting of the date and time. See date-time entity formatting for more details.

#### TextQuote

This object contains information about the quoted part of a message that is replied to by the given message.

Field | Type | Description
--- | --- | ---
text | String | Text of the quoted part of a message that is replied to by the given message
entities | Array of MessageEntity | Optional. Special entities that appear in the quote. Currently, only bold, italic, underline, strikethrough, spoiler, and custom_emoji entities are kept in quotes.
position | Integer | Approximate quote position in the original message in UTF-16 code units as specified by the sender
is_manual | True | Optional. True, if the quote was chosen manually by the message sender. Otherwise, the quote was added automatically by the server.

#### ExternalReplyInfo

This object contains information about a message that is being replied to, which may come from another chat or forum topic.

Field | Type | Description
--- | --- | ---
origin | MessageOrigin | Origin of the message replied to by the given message
chat | Chat | Optional. Chat the original message belongs to. Available only if the chat is a supergroup or a channel.
message_id | Integer | Optional. Unique message identifier inside the original chat. Available only if the original chat is a supergroup or a channel.
link_preview_options | LinkPreviewOptions | Optional. Options used for link preview generation for the original message, if it is a text message
animation | Animation | Optional. Message is an animation, information about the animation
audio | Audio | Optional. Message is an audio file, information about the file
document | Document | Optional. Message is a general file, information about the file
paid_media | PaidMediaInfo | Optional. Message contains paid media; information about the paid media
photo | Array of PhotoSize | Optional. Message is a photo, available sizes of the photo
sticker | Sticker | Optional. Message is a sticker, information about the sticker
story | Story | Optional. Message is a forwarded story
video | Video | Optional. Message is a video, information about the video
video_note | VideoNote | Optional. Message is a video note, information about the video message
voice | Voice | Optional. Message is a voice message, information about the file
has_media_spoiler | True | Optional. True, if the message media is covered by a spoiler animation
checklist | Checklist | Optional. Message is a checklist
contact | Contact | Optional. Message is a shared contact, information about the contact
dice | Dice | Optional. Message is a dice with random value
game | Game | Optional. Message is a game, information about the game. More about games »
giveaway | Giveaway | Optional. Message is a scheduled giveaway, information about the giveaway
giveaway_winners | GiveawayWinners | Optional. A giveaway with public winners was completed
invoice | Invoice | Optional. Message is an invoice for a payment, information about the invoice. More about payments »
location | Location | Optional. Message is a shared location, information about the location
poll | Poll | Optional. Message is a native poll, information about the poll
venue | Venue | Optional. Message is a venue, information about the venue

#### ReplyParameters

Describes reply parameters for the message that is being sent.

Field | Type | Description
--- | --- | ---
message_id | Integer | Identifier of the message that will be replied to in the current chat, or in the chat chat_id if it is specified
chat_id | Integer or String | Optional. If the message to be replied to is from a different chat, unique identifier for the chat or username of the channel (in the format `@channelusername`). Not supported for messages sent on behalf of a business account and messages from channel direct messages chats.
allow_sending_without_reply | Boolean | Optional. Pass True if the message should be sent even if the specified message to be replied to is not found. Always False for replies in another chat or forum topic. Always True for messages sent on behalf of a business account.
quote | String | Optional. Quoted part of the message to be replied to; 0-1024 characters after entities parsing. The quote must be an exact substring of the message to be replied to, including bold, italic, underline, strikethrough, spoiler, and custom_emoji entities. The message will fail to send if the quote isn't found in the original message.
quote_parse_mode | String | Optional. Mode for parsing entities in the quote. See formatting options for more details.
quote_entities | Array of MessageEntity | Optional. A JSON-serialized list of special entities that appear in the quote. It can be specified instead of quote_parse_mode.
quote_position | Integer | Optional. Position of the quote in the original message in UTF-16 code units
checklist_task_id | Integer | Optional. Identifier of the specific checklist task to be replied to

#### MessageOrigin

This object describes the origin of a message. It can be one of

- MessageOriginUser
- MessageOriginHiddenUser
- MessageOriginChat
- MessageOriginChannel

#### MessageOriginUser

The message was originally sent by a known user.

Field | Type | Description
--- | --- | ---
type | String | Type of the message origin, always “user”
date | Integer | Date the message was sent originally in Unix time
sender_user | User | User that sent the message originally

#### MessageOriginHiddenUser

The message was originally sent by an unknown user.

Field | Type | Description
--- | --- | ---
type | String | Type of the message origin, always “hidden_user”
date | Integer | Date the message was sent originally in Unix time
sender_user_name | String | Name of the user that sent the message originally

#### MessageOriginChat

The message was originally sent on behalf of a chat to a group chat.

Field | Type | Description
--- | --- | ---
type | String | Type of the message origin, always “chat”
date | Integer | Date the message was sent originally in Unix time
sender_chat | Chat | Chat that sent the message originally
author_signature | String | Optional. For messages originally sent by an anonymous chat administrator, original message author signature

#### MessageOriginChannel

The message was originally sent to a channel chat.

Field | Type | Description
--- | --- | ---
type | String | Type of the message origin, always “channel”
date | Integer | Date the message was sent originally in Unix time
chat | Chat | Channel chat to which the message was originally sent
message_id | Integer | Unique message identifier inside the chat
author_signature | String | Optional. Signature of the original post author

#### PhotoSize

This object represents one size of a photo or a file / sticker thumbnail.

Field | Type | Description
--- | --- | ---
file_id | String | Identifier for this file, which can be used to download or reuse the file
file_unique_id | String | Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
width | Integer | Photo width
height | Integer | Photo height
file_size | Integer | Optional. File size in bytes

#### Animation

This object represents an animation file (GIF or H.264/MPEG-4 AVC video without sound).

Field | Type | Description
--- | --- | ---
file_id | String | Identifier for this file, which can be used to download or reuse the file
file_unique_id | String | Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
width | Integer | Video width as defined by the sender
height | Integer | Video height as defined by the sender
duration | Integer | Duration of the video in seconds as defined by the sender
thumbnail | PhotoSize | Optional. Animation thumbnail as defined by the sender
file_name | String | Optional. Original animation filename as defined by the sender
mime_type | String | Optional. MIME type of the file as defined by the sender
file_size | Integer | Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.

#### Audio

This object represents an audio file to be treated as music by the Telegram clients.

Field | Type | Description
--- | --- | ---
file_id | String | Identifier for this file, which can be used to download or reuse the file
file_unique_id | String | Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
duration | Integer | Duration of the audio in seconds as defined by the sender
performer | String | Optional. Performer of the audio as defined by the sender or by audio tags
title | String | Optional. Title of the audio as defined by the sender or by audio tags
file_name | String | Optional. Original filename as defined by the sender
mime_type | String | Optional. MIME type of the file as defined by the sender
file_size | Integer | Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.
thumbnail | PhotoSize | Optional. Thumbnail of the album cover to which the music file belongs

#### Document

This object represents a general file (as opposed to photos, voice messages and audio files).

Field | Type | Description
--- | --- | ---
file_id | String | Identifier for this file, which can be used to download or reuse the file
file_unique_id | String | Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
thumbnail | PhotoSize | Optional. Document thumbnail as defined by the sender
file_name | String | Optional. Original filename as defined by the sender
mime_type | String | Optional. MIME type of the file as defined by the sender
file_size | Integer | Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.

#### Story

This object represents a story.

Field | Type | Description
--- | --- | ---
chat | Chat | Chat that posted the story
id | Integer | Unique identifier for the story in the chat

#### VideoQuality

This object represents a video file of a specific quality.

Field | Type | Description
--- | --- | ---
file_id | String | Identifier for this file, which can be used to download or reuse the file
file_unique_id | String | Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
width | Integer | Video width
height | Integer | Video height
codec | String | Codec that was used to encode the video, for example, “h264”, “h265”, or “av01”
file_size | Integer | Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.

#### Video

This object represents a video file.

Field | Type | Description
--- | --- | ---
file_id | String | Identifier for this file, which can be used to download or reuse the file
file_unique_id | String | Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
width | Integer | Video width as defined by the sender
height | Integer | Video height as defined by the sender
duration | Integer | Duration of the video in seconds as defined by the sender
thumbnail | PhotoSize | Optional. Video thumbnail
cover | Array of PhotoSize | Optional. Available sizes of the cover of the video in the message
start_timestamp | Integer | Optional. Timestamp in seconds from which the video will play in the message
qualities | Array of VideoQuality | Optional. List of available qualities of the video
file_name | String | Optional. Original filename as defined by the sender
mime_type | String | Optional. MIME type of the file as defined by the sender
file_size | Integer | Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.

#### VideoNote

This object represents a video message (available in Telegram apps as of v.4.0).

Field | Type | Description
--- | --- | ---
file_id | String | Identifier for this file, which can be used to download or reuse the file
file_unique_id | String | Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
length | Integer | Video width and height (diameter of the video message) as defined by the sender
duration | Integer | Duration of the video in seconds as defined by the sender
thumbnail | PhotoSize | Optional. Video thumbnail
file_size | Integer | Optional. File size in bytes

#### Voice

This object represents a voice note.

Field | Type | Description
--- | --- | ---
file_id | String | Identifier for this file, which can be used to download or reuse the file
file_unique_id | String | Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
duration | Integer | Duration of the audio in seconds as defined by the sender
mime_type | String | Optional. MIME type of the file as defined by the sender
file_size | Integer | Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.

#### PaidMediaInfo

Describes the paid media added to a message.

Field | Type | Description
--- | --- | ---
star_count | Integer | The number of Telegram Stars that must be paid to buy access to the media
paid_media | Array of PaidMedia | Information about the paid media

#### PaidMedia

This object describes paid media. Currently, it can be one of

- PaidMediaPreview
- PaidMediaPhoto
- PaidMediaVideo

#### PaidMediaPreview

The paid media isn't available before the payment.

Field | Type | Description
--- | --- | ---
type | String | Type of the paid media, always “preview”
width | Integer | Optional. Media width as defined by the sender
height | Integer | Optional. Media height as defined by the sender
duration | Integer | Optional. Duration of the media in seconds as defined by the sender

#### PaidMediaPhoto

The paid media is a photo.

Field | Type | Description
--- | --- | ---
type | String | Type of the paid media, always “photo”
photo | Array of PhotoSize | The photo

#### PaidMediaVideo

The paid media is a video.

Field | Type | Description
--- | --- | ---
type | String | Type of the paid media, always “video”
video | Video | The video

#### Contact

This object represents a phone contact.

Field | Type | Description
--- | --- | ---
phone_number | String | Contact's phone number
first_name | String | Contact's first name
last_name | String | Optional. Contact's last name
user_id | Integer | Optional. Contact's user identifier in Telegram. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier.
vcard | String | Optional. Additional data about the contact in the form of a vCard

#### Dice

This object represents an animated emoji that displays a random value.

Field | Type | Description
--- | --- | ---
emoji | String | Emoji on which the dice throw animation is based
value | Integer | Value of the dice, 1-6 for “”, “” and “” base emoji, 1-5 for “” and “” base emoji, 1-64 for “” base emoji

#### PollOption

This object contains information about one answer option in a poll.

Field | Type | Description
--- | --- | ---
text | String | Option text, 1-100 characters
text_entities | Array of MessageEntity | Optional. Special entities that appear in the option text. Currently, only custom emoji entities are allowed in poll option texts
voter_count | Integer | Number of users that voted for this option

#### InputPollOption

This object contains information about one answer option in a poll to be sent.

Field | Type | Description
--- | --- | ---
text | String | Option text, 1-100 characters
text_parse_mode | String | Optional. Mode for parsing entities in the text. See formatting options for more details. Currently, only custom emoji entities are allowed
text_entities | Array of MessageEntity | Optional. A JSON-serialized list of special entities that appear in the poll option text. It can be specified instead of text_parse_mode

#### PollAnswer

This object represents an answer of a user in a non-anonymous poll.

Field | Type | Description
--- | --- | ---
poll_id | String | Unique poll identifier
voter_chat | Chat | Optional. The chat that changed the answer to the poll, if the voter is anonymous
user | User | Optional. The user that changed the answer to the poll, if the voter isn't anonymous
option_ids | Array of Integer | 0-based identifiers of chosen answer options. May be empty if the vote was retracted.

#### Poll

This object contains information about a poll.

Field | Type | Description
--- | --- | ---
id | String | Unique poll identifier
question | String | Poll question, 1-300 characters
question_entities | Array of MessageEntity | Optional. Special entities that appear in the question. Currently, only custom emoji entities are allowed in poll questions
options | Array of PollOption | List of poll options
total_voter_count | Integer | Total number of users that voted in the poll
is_closed | Boolean | True, if the poll is closed
is_anonymous | Boolean | True, if the poll is anonymous
type | String | Poll type, currently can be “regular” or “quiz”
allows_multiple_answers | Boolean | True, if the poll allows multiple answers
correct_option_id | Integer | Optional. 0-based identifier of the correct answer option. Available only for polls in the quiz mode, which are closed, or was sent (not forwarded) by the bot or to the private chat with the bot.
explanation | String | Optional. Text that is shown when a user chooses an incorrect answer or taps on the lamp icon in a quiz-style poll, 0-200 characters
explanation_entities | Array of MessageEntity | Optional. Special entities like usernames, URLs, bot commands, etc. that appear in the explanation
open_period | Integer | Optional. Amount of time in seconds the poll will be active after creation
close_date | Integer | Optional. Point in time (Unix timestamp) when the poll will be automatically closed

#### ChecklistTask

Describes a task in a checklist.

Field | Type | Description
--- | --- | ---
id | Integer | Unique identifier of the task
text | String | Text of the task
text_entities | Array of MessageEntity | Optional. Special entities that appear in the task text
completed_by_user | User | Optional. User that completed the task; omitted if the task wasn't completed by a user
completed_by_chat | Chat | Optional. Chat that completed the task; omitted if the task wasn't completed by a chat
completion_date | Integer | Optional. Point in time (Unix timestamp) when the task was completed; 0 if the task wasn't completed

#### Checklist

Describes a checklist.

Field | Type | Description
--- | --- | ---
title | String | Title of the checklist
title_entities | Array of MessageEntity | Optional. Special entities that appear in the checklist title
tasks | Array of ChecklistTask | List of tasks in the checklist
others_can_add_tasks | True | Optional. True, if users other than the creator of the list can add tasks to the list
others_can_mark_tasks_as_done | True | Optional. True, if users other than the creator of the list can mark tasks as done or not done

#### InputChecklistTask

Describes a task to add to a checklist.

Field | Type | Description
--- | --- | ---
id | Integer | Unique identifier of the task; must be positive and unique among all task identifiers currently present in the checklist
text | String | Text of the task; 1-100 characters after entities parsing
parse_mode | String | Optional. Mode for parsing entities in the text. See formatting options for more details.
text_entities | Array of MessageEntity | Optional. List of special entities that appear in the text, which can be specified instead of parse_mode. Currently, only bold, italic, underline, strikethrough, spoiler, and custom_emoji entities are allowed.

#### InputChecklist

Describes a checklist to create.

Field | Type | Description
--- | --- | ---
title | String | Title of the checklist; 1-255 characters after entities parsing
parse_mode | String | Optional. Mode for parsing entities in the title. See formatting options for more details.
title_entities | Array of MessageEntity | Optional. List of special entities that appear in the title, which can be specified instead of parse_mode. Currently, only bold, italic, underline, strikethrough, spoiler, and custom_emoji entities are allowed.
tasks | Array of InputChecklistTask | List of 1-30 tasks in the checklist
others_can_add_tasks | Boolean | Optional. Pass True if other users can add tasks to the checklist
others_can_mark_tasks_as_done | Boolean | Optional. Pass True if other users can mark tasks as done or not done in the checklist

#### ChecklistTasksDone

Describes a service message about checklist tasks marked as done or not done.

Field | Type | Description
--- | --- | ---
checklist_message | Message | Optional. Message containing the checklist whose tasks were marked as done or not done. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
marked_as_done_task_ids | Array of Integer | Optional. Identifiers of the tasks that were marked as done
marked_as_not_done_task_ids | Array of Integer | Optional. Identifiers of the tasks that were marked as not done

#### ChecklistTasksAdded

Describes a service message about tasks added to a checklist.

Field | Type | Description
--- | --- | ---
checklist_message | Message | Optional. Message containing the checklist to which the tasks were added. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
tasks | Array of ChecklistTask | List of tasks added to the checklist

#### Location

This object represents a point on the map.

Field | Type | Description
--- | --- | ---
latitude | Float | Latitude as defined by the sender
longitude | Float | Longitude as defined by the sender
horizontal_accuracy | Float | Optional. The radius of uncertainty for the location, measured in meters; 0-1500
live_period | Integer | Optional. Time relative to the message sending date, during which the location can be updated; in seconds. For active live locations only.
heading | Integer | Optional. The direction in which user is moving, in degrees; 1-360. For active live locations only.
proximity_alert_radius | Integer | Optional. The maximum distance for proximity alerts about approaching another chat member, in meters. For sent live locations only.

#### Venue

This object represents a venue.

Field | Type | Description
--- | --- | ---
location | Location | Venue location. Can't be a live location
title | String | Name of the venue
address | String | Address of the venue
foursquare_id | String | Optional. Foursquare identifier of the venue
foursquare_type | String | Optional. Foursquare type of the venue. (For example, “arts_entertainment/default”, “arts_entertainment/aquarium” or “food/icecream”.)
google_place_id | String | Optional. Google Places identifier of the venue
google_place_type | String | Optional. Google Places type of the venue. (See supported types.)

#### WebAppData

Describes data sent from a Web App to the bot.

Field | Type | Description
--- | --- | ---
data | String | The data. Be aware that a bad client can send arbitrary data in this field.
button_text | String | Text of the web_app keyboard button from which the Web App was opened. Be aware that a bad client can send arbitrary data in this field.

#### ProximityAlertTriggered

This object represents the content of a service message, sent whenever a user in the chat triggers a proximity alert set by another user.

Field | Type | Description
--- | --- | ---
traveler | User | User that triggered the alert
watcher | User | User that set the alert
distance | Integer | The distance between the users

#### MessageAutoDeleteTimerChanged

This object represents a service message about a change in auto-delete timer settings.

Field | Type | Description
--- | --- | ---
message_auto_delete_time | Integer | New auto-delete time for messages in the chat; in seconds

#### ChatBoostAdded

This object represents a service message about a user boosting a chat.

Field | Type | Description
--- | --- | ---
boost_count | Integer | Number of boosts added by the user

#### BackgroundFill

This object describes the way a background is filled based on the selected colors. Currently, it can be one of

- BackgroundFillSolid
- BackgroundFillGradient
- BackgroundFillFreeformGradient

#### BackgroundFillSolid

The background is filled using the selected color.

Field | Type | Description
--- | --- | ---
type | String | Type of the background fill, always “solid”
color | Integer | The color of the background fill in the RGB24 format

#### BackgroundFillGradient

The background is a gradient fill.

Field | Type | Description
--- | --- | ---
type | String | Type of the background fill, always “gradient”
top_color | Integer | Top color of the gradient in the RGB24 format
bottom_color | Integer | Bottom color of the gradient in the RGB24 format
rotation_angle | Integer | Clockwise rotation angle of the background fill in degrees; 0-359

#### BackgroundFillFreeformGradient

The background is a freeform gradient that rotates after every message in the chat.

Field | Type | Description
--- | --- | ---
type | String | Type of the background fill, always “freeform_gradient”
colors | Array of Integer | A list of the 3 or 4 base colors that are used to generate the freeform gradient in the RGB24 format

#### BackgroundType

This object describes the type of a background. Currently, it can be one of

- BackgroundTypeFill
- BackgroundTypeWallpaper
- BackgroundTypePattern
- BackgroundTypeChatTheme

#### BackgroundTypeFill

The background is automatically filled based on the selected colors.

Field | Type | Description
--- | --- | ---
type | String | Type of the background, always “fill”
fill | BackgroundFill | The background fill
dark_theme_dimming | Integer | Dimming of the background in dark themes, as a percentage; 0-100

#### BackgroundTypeWallpaper

The background is a wallpaper in the JPEG format.

Field | Type | Description
--- | --- | ---
type | String | Type of the background, always “wallpaper”
document | Document | Document with the wallpaper
dark_theme_dimming | Integer | Dimming of the background in dark themes, as a percentage; 0-100
is_blurred | True | Optional. True, if the wallpaper is downscaled to fit in a 450x450 square and then box-blurred with radius 12
is_moving | True | Optional. True, if the background moves slightly when the device is tilted

#### BackgroundTypePattern

The background is a .PNG or .TGV (gzipped subset of SVG with MIME type “application/x-tgwallpattern”) pattern to be combined with the background fill chosen by the user.

Field | Type | Description
--- | --- | ---
type | String | Type of the background, always “pattern”
document | Document | Document with the pattern
fill | BackgroundFill | The background fill that is combined with the pattern
intensity | Integer | Intensity of the pattern when it is shown above the filled background; 0-100
is_inverted | True | Optional. True, if the background fill must be applied only to the pattern itself. All other pixels are black in this case. For dark themes only
is_moving | True | Optional. True, if the background moves slightly when the device is tilted

#### BackgroundTypeChatTheme

The background is taken directly from a built-in chat theme.

Field | Type | Description
--- | --- | ---
type | String | Type of the background, always “chat_theme”
theme_name | String | Name of the chat theme, which is usually an emoji

#### ChatBackground

This object represents a chat background.

Field | Type | Description
--- | --- | ---
type | BackgroundType | Type of the background

#### ForumTopicCreated

This object represents a service message about a new forum topic created in the chat.

Field | Type | Description
--- | --- | ---
name | String | Name of the topic
icon_color | Integer | Color of the topic icon in RGB format
icon_custom_emoji_id | String | Optional. Unique identifier of the custom emoji shown as the topic icon
is_name_implicit | True | Optional. True, if the name of the topic wasn't specified explicitly by its creator and likely needs to be changed by the bot

#### ForumTopicClosed

This object represents a service message about a forum topic closed in the chat. Currently holds no information.

#### ForumTopicEdited

This object represents a service message about an edited forum topic.

Field | Type | Description
--- | --- | ---
name | String | Optional. New name of the topic, if it was edited
icon_custom_emoji_id | String | Optional. New identifier of the custom emoji shown as the topic icon, if it was edited; an empty string if the icon was removed

#### ForumTopicReopened

This object represents a service message about a forum topic reopened in the chat. Currently holds no information.

#### GeneralForumTopicHidden

This object represents a service message about General forum topic hidden in the chat. Currently holds no information.

#### GeneralForumTopicUnhidden

This object represents a service message about General forum topic unhidden in the chat. Currently holds no information.

#### SharedUser

This object contains information about a user that was shared with the bot using a KeyboardButtonRequestUsers button.

Field | Type | Description
--- | --- | ---
user_id | Integer | Identifier of the shared user. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so 64-bit integers or double-precision float types are safe for storing these identifiers. The bot may not have access to the user and could be unable to use this identifier, unless the user is already known to the bot by some other means.
first_name | String | Optional. First name of the user, if the name was requested by the bot
last_name | String | Optional. Last name of the user, if the name was requested by the bot
username | String | Optional. Username of the user, if the username was requested by the bot
photo | Array of PhotoSize | Optional. Available sizes of the chat photo, if the photo was requested by the bot

#### UsersShared

This object contains information about the users whose identifiers were shared with the bot using a KeyboardButtonRequestUsers button.

Field | Type | Description
--- | --- | ---
request_id | Integer | Identifier of the request
users | Array of SharedUser | Information about users shared with the bot.

#### ChatShared

This object contains information about a chat that was shared with the bot using a KeyboardButtonRequestChat button.

Field | Type | Description
--- | --- | ---
request_id | Integer | Identifier of the request
chat_id | Integer | Identifier of the shared chat. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier. The bot may not have access to the chat and could be unable to use this identifier, unless the chat is already known to the bot by some other means.
title | String | Optional. Title of the chat, if the title was requested by the bot.
username | String | Optional. Username of the chat, if the username was requested by the bot and available.
photo | Array of PhotoSize | Optional. Available sizes of the chat photo, if the photo was requested by the bot

#### WriteAccessAllowed

This object represents a service message about a user allowing a bot to write messages after adding it to the attachment menu, launching a Web App from a link, or accepting an explicit request from a Web App sent by the method requestWriteAccess.

Field | Type | Description
--- | --- | ---
from_request | Boolean | Optional. True, if the access was granted after the user accepted an explicit request from a Web App sent by the method requestWriteAccess
web_app_name | String | Optional. Name of the Web App, if the access was granted when the Web App was launched from a link
from_attachment_menu | Boolean | Optional. True, if the access was granted when the bot was added to the attachment or side menu

#### VideoChatScheduled

This object represents a service message about a video chat scheduled in the chat.

Field | Type | Description
--- | --- | ---
start_date | Integer | Point in time (Unix timestamp) when the video chat is supposed to be started by a chat administrator

#### VideoChatStarted

This object represents a service message about a video chat started in the chat. Currently holds no information.

#### VideoChatEnded

This object represents a service message about a video chat ended in the chat.

Field | Type | Description
--- | --- | ---
duration | Integer | Video chat duration in seconds

#### VideoChatParticipantsInvited

This object represents a service message about new members invited to a video chat.

Field | Type | Description
--- | --- | ---
users | Array of User | New members that were invited to the video chat

#### PaidMessagePriceChanged

Describes a service message about a change in the price of paid messages within a chat.

Field | Type | Description
--- | --- | ---
paid_message_star_count | Integer | The new number of Telegram Stars that must be paid by non-administrator users of the supergroup chat for each sent message

#### DirectMessagePriceChanged

Describes a service message about a change in the price of direct messages sent to a channel chat.

Field | Type | Description
--- | --- | ---
are_direct_messages_enabled | Boolean | True, if direct messages are enabled for the channel chat; false otherwise
direct_message_star_count | Integer | Optional. The new number of Telegram Stars that must be paid by users for each direct message sent to the channel. Does not apply to users who have been exempted by administrators. Defaults to 0.

#### SuggestedPostApproved

Describes a service message about the approval of a suggested post.

Field | Type | Description
--- | --- | ---
suggested_post_message | Message | Optional. Message containing the suggested post. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
price | SuggestedPostPrice | Optional. Amount paid for the post
send_date | Integer | Date when the post will be published

#### SuggestedPostApprovalFailed

Describes a service message about the failed approval of a suggested post. Currently, only caused by insufficient user funds at the time of approval.

Field | Type | Description
--- | --- | ---
suggested_post_message | Message | Optional. Message containing the suggested post whose approval has failed. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
price | SuggestedPostPrice | Expected price of the post

#### SuggestedPostDeclined

Describes a service message about the rejection of a suggested post.

Field | Type | Description
--- | --- | ---
suggested_post_message | Message | Optional. Message containing the suggested post. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
comment | String | Optional. Comment with which the post was declined

#### SuggestedPostPaid

Describes a service message about a successful payment for a suggested post.

Field | Type | Description
--- | --- | ---
suggested_post_message | Message | Optional. Message containing the suggested post. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
currency | String | Currency in which the payment was made. Currently, one of “XTR” for Telegram Stars or “TON” for toncoins
amount | Integer | Optional. The amount of the currency that was received by the channel in nanotoncoins; for payments in toncoins only
star_amount | StarAmount | Optional. The amount of Telegram Stars that was received by the channel; for payments in Telegram Stars only

#### SuggestedPostRefunded

Describes a service message about a payment refund for a suggested post.

Field | Type | Description
--- | --- | ---
suggested_post_message | Message | Optional. Message containing the suggested post. Note that the Message object in this field will not contain the reply_to_message field even if it itself is a reply.
reason | String | Reason for the refund. Currently, one of “post_deleted” if the post was deleted within 24 hours of being posted or removed from scheduled messages without being posted, or “payment_refunded” if the payer refunded their payment.

#### GiveawayCreated

This object represents a service message about the creation of a scheduled giveaway.

Field | Type | Description
--- | --- | ---
prize_star_count | Integer | Optional. The number of Telegram Stars to be split between giveaway winners; for Telegram Star giveaways only

#### Giveaway

This object represents a message about a scheduled giveaway.

Field | Type | Description
--- | --- | ---
chats | Array of Chat | The list of chats which the user must join to participate in the giveaway
winners_selection_date | Integer | Point in time (Unix timestamp) when winners of the giveaway will be selected
winner_count | Integer | The number of users which are supposed to be selected as winners of the giveaway
only_new_members | True | Optional. True, if only users who join the chats after the giveaway started should be eligible to win
has_public_winners | True | Optional. True, if the list of giveaway winners will be visible to everyone
prize_description | String | Optional. Description of additional giveaway prize
country_codes | Array of String | Optional. A list of two-letter ISO 3166-1 alpha-2 country codes indicating the countries from which eligible users for the giveaway must come. If empty, then all users can participate in the giveaway. Users with a phone number that was bought on Fragment can always participate in giveaways.
prize_star_count | Integer | Optional. The number of Telegram Stars to be split between giveaway winners; for Telegram Star giveaways only
premium_subscription_month_count | Integer | Optional. The number of months the Telegram Premium subscription won from the giveaway will be active for; for Telegram Premium giveaways only

#### GiveawayWinners

This object represents a message about the completion of a giveaway with public winners.

Field | Type | Description
--- | --- | ---
chat | Chat | The chat that created the giveaway
giveaway_message_id | Integer | Identifier of the message with the giveaway in the chat
winners_selection_date | Integer | Point in time (Unix timestamp) when winners of the giveaway were selected
winner_count | Integer | Total number of winners in the giveaway
winners | Array of User | List of up to 100 winners of the giveaway
additional_chat_count | Integer | Optional. The number of other chats the user had to join in order to be eligible for the giveaway
prize_star_count | Integer | Optional. The number of Telegram Stars that were split between giveaway winners; for Telegram Star giveaways only
premium_subscription_month_count | Integer | Optional. The number of months the Telegram Premium subscription won from the giveaway will be active for; for Telegram Premium giveaways only
unclaimed_prize_count | Integer | Optional. Number of undistributed prizes
only_new_members | True | Optional. True, if only users who had joined the chats after the giveaway started were eligible to win
was_refunded | True | Optional. True, if the giveaway was canceled because the payment for it was refunded
prize_description | String | Optional. Description of additional giveaway prize

#### GiveawayCompleted

This object represents a service message about the completion of a giveaway without public winners.

Field | Type | Description
--- | --- | ---
winner_count | Integer | Number of winners in the giveaway
unclaimed_prize_count | Integer | Optional. Number of undistributed prizes
giveaway_message | Message | Optional. Message with the giveaway that was completed, if it wasn't deleted
is_star_giveaway | True | Optional. True, if the giveaway is a Telegram Star giveaway. Otherwise, currently, the giveaway is a Telegram Premium giveaway.

#### LinkPreviewOptions

Describes the options used for link preview generation.

Field | Type | Description
--- | --- | ---
is_disabled | Boolean | Optional. True, if the link preview is disabled
url | String | Optional. URL to use for the link preview. If empty, then the first URL found in the message text will be used
prefer_small_media | Boolean | Optional. True, if the media in the link preview is supposed to be shrunk; ignored if the URL isn't explicitly specified or media size change isn't supported for the preview
prefer_large_media | Boolean | Optional. True, if the media in the link preview is supposed to be enlarged; ignored if the URL isn't explicitly specified or media size change isn't supported for the preview
show_above_text | Boolean | Optional. True, if the link preview must be shown above the message text; otherwise, the link preview will be shown below the message text

#### SuggestedPostPrice

Describes the price of a suggested post.

Field | Type | Description
--- | --- | ---
currency | String | Currency in which the post will be paid. Currently, must be one of “XTR” for Telegram Stars or “TON” for toncoins
amount | Integer | The amount of the currency that will be paid for the post in the smallest units of the currency, i.e. Telegram Stars or nanotoncoins. Currently, price in Telegram Stars must be between 5 and 100000, and price in nanotoncoins must be between 10000000 and 10000000000000.

#### SuggestedPostInfo

Contains information about a suggested post.

Field | Type | Description
--- | --- | ---
state | String | State of the suggested post. Currently, it can be one of “pending”, “approved”, “declined”.
price | SuggestedPostPrice | Optional. Proposed price of the post. If the field is omitted, then the post is unpaid.
send_date | Integer | Optional. Proposed send date of the post. If the field is omitted, then the post can be published at any time within 30 days at the sole discretion of the user or administrator who approves it.

#### SuggestedPostParameters

Contains parameters of a post that is being suggested by the bot.

Field | Type | Description
--- | --- | ---
price | SuggestedPostPrice | Optional. Proposed price for the post. If the field is omitted, then the post is unpaid.
send_date | Integer | Optional. Proposed send date of the post. If specified, then the date must be between 300 second and 2678400 seconds (30 days) in the future. If the field is omitted, then the post can be published at any time within 30 days at the sole discretion of the user who approves it.

#### DirectMessagesTopic

Describes a topic of a direct messages chat.

Field | Type | Description
--- | --- | ---
topic_id | Integer | Unique identifier of the topic. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier.
user | User | Optional. Information about the user that created the topic. Currently, it is always present

#### UserProfilePhotos

This object represent a user's profile pictures.

Field | Type | Description
--- | --- | ---
total_count | Integer | Total number of profile pictures the target user has
photos | Array of Array of PhotoSize | Requested profile pictures (in up to 4 sizes each)

#### UserProfileAudios

This object represents the audios displayed on a user's profile.

Field | Type | Description
--- | --- | ---
total_count | Integer | Total number of profile audios for the target user
audios | Array of Audio | Requested profile audios

#### File

This object represents a file ready to be downloaded. The file can be downloaded via the link `https://api.telegram.org/file/bot<token>/<file_path>`. It is guaranteed that the link will be valid for at least 1 hour. When the link expires, a new one can be requested by calling getFile.

> The maximum file size to download is 20 MB

Field | Type | Description
--- | --- | ---
file_id | String | Identifier for this file, which can be used to download or reuse the file
file_unique_id | String | Unique identifier for this file, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
file_size | Integer | Optional. File size in bytes. It can be bigger than 2^31 and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this value.
file_path | String | Optional. File path. Use `https://api.telegram.org/file/bot<token>/<file_path>` to get the file.

#### WebAppInfo

Describes a Web App.

Field | Type | Description
--- | --- | ---
url | String | An HTTPS URL of a Web App to be opened with additional data as specified in Initializing Web Apps

#### ReplyKeyboardMarkup

This object represents a custom keyboard with reply options (see Introduction to bots for details and examples). Not supported in channels and for messages sent on behalf of a Telegram Business account.

Field | Type | Description
--- | --- | ---
keyboard | Array of Array of KeyboardButton | Array of button rows, each represented by an Array of KeyboardButton objects
is_persistent | Boolean | Optional. Requests clients to always show the keyboard when the regular keyboard is hidden. Defaults to false, in which case the custom keyboard can be hidden and opened with a keyboard icon.
resize_keyboard | Boolean | Optional. Requests clients to resize the keyboard vertically for optimal fit (e.g., make the keyboard smaller if there are just two rows of buttons). Defaults to false, in which case the custom keyboard is always of the same height as the app's standard keyboard.
one_time_keyboard | Boolean | Optional. Requests clients to hide the keyboard as soon as it's been used. The keyboard will still be available, but clients will automatically display the usual letter-keyboard in the chat - the user can press a special button in the input field to see the custom keyboard again. Defaults to false.
input_field_placeholder | String | Optional. The placeholder to be shown in the input field when the keyboard is active; 1-64 characters
selective | Boolean | Optional. Use this parameter if you want to show the keyboard to specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply to a message in the same chat and forum topic, sender of the original message. Example: A user requests to change the bot's language, bot replies to the request with a keyboard to select the new language. Other users in the group don't see the keyboard.

#### KeyboardButton

This object represents one button of the reply keyboard. At most one of the fields other than text, icon_custom_emoji_id, and style must be used to specify the type of the button. For simple text buttons, String can be used instead of this object to specify the button text.

Field | Type | Description
--- | --- | ---
text | String | Text of the button. If none of the fields other than text, icon_custom_emoji_id, and style are used, it will be sent as a message when the button is pressed
icon_custom_emoji_id | String | Optional. Unique identifier of the custom emoji shown before the text of the button. Can only be used by bots that purchased additional usernames on Fragment or in the messages directly sent by the bot to private, group and supergroup chats if the owner of the bot has a Telegram Premium subscription.
style | String | Optional. Style of the button. Must be one of “danger” (red), “success” (green) or “primary” (blue). If omitted, then an app-specific style is used.
request_users | KeyboardButtonRequestUsers | Optional. If specified, pressing the button will open a list of suitable users. Identifiers of selected users will be sent to the bot in a “users_shared” service message. Available in private chats only.
request_chat | KeyboardButtonRequestChat | Optional. If specified, pressing the button will open a list of suitable chats. Tapping on a chat will send its identifier to the bot in a “chat_shared” service message. Available in private chats only.
request_contact | Boolean | Optional. If True, the user's phone number will be sent as a contact when the button is pressed. Available in private chats only.
request_location | Boolean | Optional. If True, the user's current location will be sent when the button is pressed. Available in private chats only.
request_poll | KeyboardButtonPollType | Optional. If specified, the user will be asked to create a poll and send it to the bot when the button is pressed. Available in private chats only.
web_app | WebAppInfo | Optional. If specified, the described Web App will be launched when the button is pressed. The Web App will be able to send a “web_app_data” service message. Available in private chats only.

#### KeyboardButtonRequestUsers

This object defines the criteria used to request suitable users. Information about the selected users will be shared with the bot when the corresponding button is pressed. More about requesting users »

Field | Type | Description
--- | --- | ---
request_id | Integer | Signed 32-bit identifier of the request that will be received back in the UsersShared object. Must be unique within the message
user_is_bot | Boolean | Optional. Pass True to request bots, pass False to request regular users. If not specified, no additional restrictions are applied.
user_is_premium | Boolean | Optional. Pass True to request premium users, pass False to request non-premium users. If not specified, no additional restrictions are applied.
max_quantity | Integer | Optional. The maximum number of users to be selected; 1-10. Defaults to 1.
request_name | Boolean | Optional. Pass True to request the users' first and last names
request_username | Boolean | Optional. Pass True to request the users' usernames
request_photo | Boolean | Optional. Pass True to request the users' photos

#### KeyboardButtonRequestChat

This object defines the criteria used to request a suitable chat. Information about the selected chat will be shared with the bot when the corresponding button is pressed. The bot will be granted requested rights in the chat if appropriate. More about requesting chats ».

Field | Type | Description
--- | --- | ---
request_id | Integer | Signed 32-bit identifier of the request, which will be received back in the ChatShared object. Must be unique within the message
chat_is_channel | Boolean | Pass True to request a channel chat, pass False to request a group or a supergroup chat.
chat_is_forum | Boolean | Optional. Pass True to request a forum supergroup, pass False to request a non-forum chat. If not specified, no additional restrictions are applied.
chat_has_username | Boolean | Optional. Pass True to request a supergroup or a channel with a username, pass False to request a chat without a username. If not specified, no additional restrictions are applied.
chat_is_created | Boolean | Optional. Pass True to request a chat owned by the user. Otherwise, no additional restrictions are applied.
user_administrator_rights | ChatAdministratorRights | Optional. A JSON-serialized object listing the required administrator rights of the user in the chat. The rights must be a superset of bot_administrator_rights. If not specified, no additional restrictions are applied.
bot_administrator_rights | ChatAdministratorRights | Optional. A JSON-serialized object listing the required administrator rights of the bot in the chat. The rights must be a subset of user_administrator_rights. If not specified, no additional restrictions are applied.
bot_is_member | Boolean | Optional. Pass True to request a chat with the bot as a member. Otherwise, no additional restrictions are applied.
request_title | Boolean | Optional. Pass True to request the chat's title
request_username | Boolean | Optional. Pass True to request the chat's username
request_photo | Boolean | Optional. Pass True to request the chat's photo

#### KeyboardButtonPollType

This object represents type of a poll, which is allowed to be created and sent when the corresponding button is pressed.

Field | Type | Description
--- | --- | ---
type | String | Optional. If quiz is passed, the user will be allowed to create only polls in the quiz mode. If regular is passed, only regular polls will be allowed. Otherwise, the user will be allowed to create a poll of any type.

#### ReplyKeyboardRemove

Upon receiving a message with this object, Telegram clients will remove the current custom keyboard and display the default letter-keyboard. By default, custom keyboards are displayed until a new keyboard is sent by a bot. An exception is made for one-time keyboards that are hidden immediately after the user presses a button (see ReplyKeyboardMarkup). Not supported in channels and for messages sent on behalf of a Telegram Business account.

Field | Type | Description
--- | --- | ---
remove_keyboard | True | Requests clients to remove the custom keyboard (user will not be able to summon this keyboard; if you want to hide the keyboard from sight but keep it accessible, use one_time_keyboard in ReplyKeyboardMarkup)
selective | Boolean | Optional. Use this parameter if you want to remove the keyboard for specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply to a message in the same chat and forum topic, sender of the original message. Example: A user votes in a poll, bot returns confirmation message in reply to the vote and removes the keyboard for that user, while still showing the keyboard with poll options to users who haven't voted yet.

#### InlineKeyboardMarkup

This object represents an inline keyboard that appears right next to the message it belongs to.

Field | Type | Description
--- | --- | ---
inline_keyboard | Array of Array of InlineKeyboardButton | Array of button rows, each represented by an Array of InlineKeyboardButton objects

#### InlineKeyboardButton

This object represents one button of an inline keyboard. Exactly one of the fields other than text, icon_custom_emoji_id, and style must be used to specify the type of the button.

Field | Type | Description
--- | --- | ---
text | String | Label text on the button
icon_custom_emoji_id | String | Optional. Unique identifier of the custom emoji shown before the text of the button. Can only be used by bots that purchased additional usernames on Fragment or in the messages directly sent by the bot to private, group and supergroup chats if the owner of the bot has a Telegram Premium subscription.
style | String | Optional. Style of the button. Must be one of “danger” (red), “success” (green) or “primary” (blue). If omitted, then an app-specific style is used.
url | String | Optional. HTTP or tg:// URL to be opened when the button is pressed. Links `tg://user?id=<user_id>` can be used to mention a user by their identifier without using a username, if this is allowed by their privacy settings.
callback_data | String | Optional. Data to be sent in a callback query to the bot when the button is pressed, 1-64 bytes
web_app | WebAppInfo | Optional. Description of the Web App that will be launched when the user presses the button. The Web App will be able to send an arbitrary message on behalf of the user using the method answerWebAppQuery. Available only in private chats between a user and the bot. Not supported for messages sent on behalf of a Telegram Business account.
login_url | LoginUrl | Optional. An HTTPS URL used to automatically authorize the user. Can be used as a replacement for the Telegram Login Widget.
switch_inline_query | String | Optional. If set, pressing the button will prompt the user to select one of their chats, open that chat and insert the bot's username and the specified inline query in the input field. May be empty, in which case just the bot's username will be inserted. Not supported for messages sent in channel direct messages chats and on behalf of a Telegram Business account.
switch_inline_query_current_chat | String | Optional. If set, pressing the button will insert the bot's username and the specified inline query in the current chat's input field. May be empty, in which case only the bot's username will be inserted. This offers a quick way for the user to open your bot in inline mode in the same chat - good for selecting something from multiple options. Not supported in channels and for messages sent in channel direct messages chats and on behalf of a Telegram Business account.
switch_inline_query_chosen_chat | SwitchInlineQueryChosenChat | Optional. If set, pressing the button will prompt the user to select one of their chats of the specified type, open that chat and insert the bot's username and the specified inline query in the input field. Not supported for messages sent in channel direct messages chats and on behalf of a Telegram Business account.
copy_text | CopyTextButton | Optional. Description of the button that copies the specified text to the clipboard.
callback_game | CallbackGame | Optional. Description of the game that will be launched when the user presses the button. NOTE: This type of button must always be the first button in the first row.
pay | Boolean | Optional. Specify True, to send a Pay button. Substrings “” and “XTR” in the buttons's text will be replaced with a Telegram Star icon. NOTE: This type of button must always be the first button in the first row and can only be used in invoice messages.

#### LoginUrl

This object represents a parameter of the inline keyboard button used to automatically authorize a user. Serves as a great replacement for the Telegram Login Widget when the user is coming from Telegram. All the user needs to do is tap/click a button and confirm that they want to log in:

Telegram apps support these buttons as of version 5.7.

> Sample bot: @discussbot

Field | Type | Description
--- | --- | ---
url | String | An HTTPS URL to be opened with user authorization data added to the query string when the button is pressed. If the user refuses to provide authorization data, the original URL without information about the user will be opened. The data added is the same as described in Receiving authorization data. NOTE: You must always check the hash of the received data to verify the authentication and the integrity of the data as described in Checking authorization.
forward_text | String | Optional. New text of the button in forwarded messages.
bot_username | String | Optional. Username of a bot, which will be used for user authorization. See Setting up a bot for more details. If not specified, the current bot's username will be assumed. The url's domain must be the same as the domain linked with the bot. See Linking your domain to the bot for more details.
request_write_access | Boolean | Optional. Pass True to request the permission for your bot to send messages to the user.

#### SwitchInlineQueryChosenChat

This object represents an inline button that switches the current user to inline mode in a chosen chat, with an optional default inline query.

Field | Type | Description
--- | --- | ---
query | String | Optional. The default inline query to be inserted in the input field. If left empty, only the bot's username will be inserted
allow_user_chats | Boolean | Optional. True, if private chats with users can be chosen
allow_bot_chats | Boolean | Optional. True, if private chats with bots can be chosen
allow_group_chats | Boolean | Optional. True, if group and supergroup chats can be chosen
allow_channel_chats | Boolean | Optional. True, if channel chats can be chosen

#### CopyTextButton

This object represents an inline keyboard button that copies specified text to the clipboard.

Field | Type | Description
--- | --- | ---
text | String | The text to be copied to the clipboard; 1-256 characters

#### CallbackQuery

This object represents an incoming callback query from a callback button in an inline keyboard. If the button that originated the query was attached to a message sent by the bot, the field message will be present. If the button was attached to a message sent via the bot (in inline mode), the field inline_message_id will be present. Exactly one of the fields data or game_short_name will be present.

Field | Type | Description
--- | --- | ---
id | String | Unique identifier for this query
from | User | Sender
message | MaybeInaccessibleMessage | Optional. Message sent by the bot with the callback button that originated the query
inline_message_id | String | Optional. Identifier of the message sent via the bot in inline mode, that originated the query.
chat_instance | String | Global identifier, uniquely corresponding to the chat to which the message with the callback button was sent. Useful for high scores in games.
data | String | Optional. Data associated with the callback button. Be aware that the message originated the query can contain no callback buttons with this data.
game_short_name | String | Optional. Short name of a Game to be returned, serves as the unique identifier for the game

> NOTE: After the user presses a callback button, Telegram clients will display a progress bar until you call answerCallbackQuery. It is, therefore, necessary to react by calling answerCallbackQuery even if no notification to the user is needed (e.g., without specifying any of the optional parameters).

#### ForceReply

Upon receiving a message with this object, Telegram clients will display a reply interface to the user (act as if the user has selected the bot's message and tapped 'Reply'). This can be extremely useful if you want to create user-friendly step-by-step interfaces without having to sacrifice privacy mode. Not supported in channels and for messages sent on behalf of a Telegram Business account.

Field | Type | Description
--- | --- | ---
force_reply | True | Shows reply interface to the user, as if they manually selected the bot's message and tapped 'Reply'
input_field_placeholder | String | Optional. The placeholder to be shown in the input field when the reply is active; 1-64 characters
selective | Boolean | Optional. Use this parameter if you want to force reply from specific users only. Targets: 1) users that are @mentioned in the text of the Message object; 2) if the bot's message is a reply to a message in the same chat and forum topic, sender of the original message.

> Example: A poll bot for groups runs in privacy mode (only receives commands, replies to its messages and mentions). There could be two ways to create a new poll:

> - Explain the user how to send a command with parameters (e.g. /newpoll question answer1 answer2). May be appealing for hardcore users but lacks modern day polish.
> - Guide the user through a step-by-step process. 'Please send me your question', 'Cool, now let's add the first answer option', 'Great. Keep adding answer options, then send /done when you're ready'.

> The last option is definitely more attractive. And if you use ForceReply in your bot's questions, it will receive the user's answers even if it only receives replies, commands and mentions - without any extra work for the user.

#### ChatPhoto

This object represents a chat photo.

Field | Type | Description
--- | --- | ---
small_file_id | String | File identifier of small (160x160) chat photo. This file_id can be used only for photo download and only for as long as the photo is not changed.
small_file_unique_id | String | Unique file identifier of small (160x160) chat photo, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.
big_file_id | String | File identifier of big (640x640) chat photo. This file_id can be used only for photo download and only for as long as the photo is not changed.
big_file_unique_id | String | Unique file identifier of big (640x640) chat photo, which is supposed to be the same over time and for different bots. Can't be used to download or reuse the file.

#### ChatInviteLink

Represents an invite link for a chat.

Field | Type | Description
--- | --- | ---
invite_link | String | The invite link. If the link was created by another chat administrator, then the second part of the link will be replaced with “…”.
creator | User | Creator of the link
creates_join_request | Boolean | True, if users joining the chat via the link need to be approved by chat administrators
is_primary | Boolean | True, if the link is primary
is_revoked | Boolean | True, if the link is revoked
name | String | Optional. Invite link name
expire_date | Integer | Optional. Point in time (Unix timestamp) when the link will expire or has been expired
member_limit | Integer | Optional. The maximum number of users that can be members of the chat simultaneously after joining the chat via this invite link; 1-99999
pending_join_request_count | Integer | Optional. Number of pending join requests created using this link
subscription_period | Integer | Optional. The number of seconds the subscription will be active for before the next payment
subscription_price | Integer | Optional. The amount of Telegram Stars a user must pay initially and after each subsequent subscription period to be a member of the chat using the link

#### ChatAdministratorRights

Represents the rights of an administrator in a chat.

Field | Type | Description
--- | --- | ---
is_anonymous | Boolean | True, if the user's presence in the chat is hidden
can_manage_chat | Boolean | True, if the administrator can access the chat event log, get boost list, see hidden supergroup and channel members, report spam messages, ignore slow mode, and send messages to the chat without paying Telegram Stars. Implied by any other administrator privilege.
can_delete_messages | Boolean | True, if the administrator can delete messages of other users
can_manage_video_chats | Boolean | True, if the administrator can manage video chats
can_restrict_members | Boolean | True, if the administrator can restrict, ban or unban chat members, or access supergroup statistics
can_promote_members | Boolean | True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that they have promoted, directly or indirectly (promoted by administrators that were appointed by the user)
can_change_info | Boolean | True, if the user is allowed to change the chat title, photo and other settings
can_invite_users | Boolean | True, if the user is allowed to invite new users to the chat
can_post_stories | Boolean | True, if the administrator can post stories to the chat
can_edit_stories | Boolean | True, if the administrator can edit stories posted by other users, post stories to the chat page, pin chat stories, and access the chat's story archive
can_delete_stories | Boolean | True, if the administrator can delete stories posted by other users
can_post_messages | Boolean | Optional. True, if the administrator can post messages in the channel, approve suggested posts, or access channel statistics; for channels only
can_edit_messages | Boolean | Optional. True, if the administrator can edit messages of other users and can pin messages; for channels only
can_pin_messages | Boolean | Optional. True, if the user is allowed to pin messages; for groups and supergroups only
can_manage_topics | Boolean | Optional. True, if the user is allowed to create, rename, close, and reopen forum topics; for supergroups only
can_manage_direct_messages | Boolean | Optional. True, if the administrator can manage direct messages of the channel and decline suggested posts; for channels only
can_manage_tags | Boolean | Optional. True, if the administrator can edit the tags of regular members; for groups and supergroups only. If omitted defaults to the value of can_pin_messages.

#### ChatMemberUpdated

This object represents changes in the status of a chat member.

Field | Type | Description
--- | --- | ---
chat | Chat | Chat the user belongs to
from | User | Performer of the action, which resulted in the change
date | Integer | Date the change was done in Unix time
old_chat_member | ChatMember | Previous information about the chat member
new_chat_member | ChatMember | New information about the chat member
invite_link | ChatInviteLink | Optional. Chat invite link, which was used by the user to join the chat; for joining by invite link events only.
via_join_request | Boolean | Optional. True, if the user joined the chat after sending a direct join request without using an invite link and being approved by an administrator
via_chat_folder_invite_link | Boolean | Optional. True, if the user joined the chat via a chat folder invite link

#### ChatMember

This object contains information about one member of a chat. Currently, the following 6 types of chat members are supported:

- ChatMemberOwner
- ChatMemberAdministrator
- ChatMemberMember
- ChatMemberRestricted
- ChatMemberLeft
- ChatMemberBanned

#### ChatMemberOwner

Represents a chat member that owns the chat and has all administrator privileges.

Field | Type | Description
--- | --- | ---
status | String | The member's status in the chat, always “creator”
user | User | Information about the user
is_anonymous | Boolean | True, if the user's presence in the chat is hidden
custom_title | String | Optional. Custom title for this user

#### ChatMemberAdministrator

Represents a chat member that has some additional privileges.

Field | Type | Description
--- | --- | ---
status | String | The member's status in the chat, always “administrator”
user | User | Information about the user
can_be_edited | Boolean | True, if the bot is allowed to edit administrator privileges of that user
is_anonymous | Boolean | True, if the user's presence in the chat is hidden
can_manage_chat | Boolean | True, if the administrator can access the chat event log, get boost list, see hidden supergroup and channel members, report spam messages, ignore slow mode, and send messages to the chat without paying Telegram Stars. Implied by any other administrator privilege.
can_delete_messages | Boolean | True, if the administrator can delete messages of other users
can_manage_video_chats | Boolean | True, if the administrator can manage video chats
can_restrict_members | Boolean | True, if the administrator can restrict, ban or unban chat members, or access supergroup statistics
can_promote_members | Boolean | True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that they have promoted, directly or indirectly (promoted by administrators that were appointed by the user)
can_change_info | Boolean | True, if the user is allowed to change the chat title, photo and other settings
can_invite_users | Boolean | True, if the user is allowed to invite new users to the chat
can_post_stories | Boolean | True, if the administrator can post stories to the chat
can_edit_stories | Boolean | True, if the administrator can edit stories posted by other users, post stories to the chat page, pin chat stories, and access the chat's story archive
can_delete_stories | Boolean | True, if the administrator can delete stories posted by other users
can_post_messages | Boolean | Optional. True, if the administrator can post messages in the channel, approve suggested posts, or access channel statistics; for channels only
can_edit_messages | Boolean | Optional. True, if the administrator can edit messages of other users and can pin messages; for channels only
can_pin_messages | Boolean | Optional. True, if the user is allowed to pin messages; for groups and supergroups only
can_manage_topics | Boolean | Optional. True, if the user is allowed to create, rename, close, and reopen forum topics; for supergroups only
can_manage_direct_messages | Boolean | Optional. True, if the administrator can manage direct messages of the channel and decline suggested posts; for channels only
can_manage_tags | Boolean | Optional. True, if the administrator can edit the tags of regular members; for groups and supergroups only. If omitted defaults to the value of can_pin_messages.
custom_title | String | Optional. Custom title for this user

#### ChatMemberMember

Represents a chat member that has no additional privileges or restrictions.

Field | Type | Description
--- | --- | ---
status | String | The member's status in the chat, always “member”
tag | String | Optional. Tag of the member
user | User | Information about the user
until_date | Integer | Optional. Date when the user's subscription will expire; Unix time

#### ChatMemberRestricted

Represents a chat member that is under certain restrictions in the chat. Supergroups only.

Field | Type | Description
--- | --- | ---
status | String | The member's status in the chat, always “restricted”
tag | String | Optional. Tag of the member
user | User | Information about the user
is_member | Boolean | True, if the user is a member of the chat at the moment of the request
can_send_messages | Boolean | True, if the user is allowed to send text messages, contacts, giveaways, giveaway winners, invoices, locations and venues
can_send_audios | Boolean | True, if the user is allowed to send audios
can_send_documents | Boolean | True, if the user is allowed to send documents
can_send_photos | Boolean | True, if the user is allowed to send photos
can_send_videos | Boolean | True, if the user is allowed to send videos
can_send_video_notes | Boolean | True, if the user is allowed to send video notes
can_send_voice_notes | Boolean | True, if the user is allowed to send voice notes
can_send_polls | Boolean | True, if the user is allowed to send polls and checklists
can_send_other_messages | Boolean | True, if the user is allowed to send animations, games, stickers and use inline bots
can_add_web_page_previews | Boolean | True, if the user is allowed to add web page previews to their messages
can_edit_tag | Boolean | True, if the user is allowed to edit their own tag
can_change_info | Boolean | True, if the user is allowed to change the chat title, photo and other settings
can_invite_users | Boolean | True, if the user is allowed to invite new users to the chat
can_pin_messages | Boolean | True, if the user is allowed to pin messages
can_manage_topics | Boolean | True, if the user is allowed to create forum topics
until_date | Integer | Date when restrictions will be lifted for this user; Unix time. If 0, then the user is restricted forever

#### ChatMemberLeft

Represents a chat member that isn't currently a member of the chat, but may join it themselves.

Field | Type | Description
--- | --- | ---
status | String | The member's status in the chat, always “left”
user | User | Information about the user

#### ChatMemberBanned

Represents a chat member that was banned in the chat and can't return to the chat or view chat messages.

Field | Type | Description
--- | --- | ---
status | String | The member's status in the chat, always “kicked”
user | User | Information about the user
until_date | Integer | Date when restrictions will be lifted for this user; Unix time. If 0, then the user is banned forever

#### ChatJoinRequest

Represents a join request sent to a chat.

Field | Type | Description
--- | --- | ---
chat | Chat | Chat to which the request was sent
from | User | User that sent the join request
user_chat_id | Integer | Identifier of a private chat with the user who sent the join request. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier. The bot can use this identifier for 5 minutes to send messages until the join request is processed, assuming no other administrator contacted the user.
date | Integer | Date the request was sent in Unix time
bio | String | Optional. Bio of the user.
invite_link | ChatInviteLink | Optional. Chat invite link that was used by the user to send the join request

#### ChatPermissions

Describes actions that a non-administrator user is allowed to take in a chat.

Field | Type | Description
--- | --- | ---
can_send_messages | Boolean | Optional. True, if the user is allowed to send text messages, contacts, giveaways, giveaway winners, invoices, locations and venues
can_send_audios | Boolean | Optional. True, if the user is allowed to send audios
can_send_documents | Boolean | Optional. True, if the user is allowed to send documents
can_send_photos | Boolean | Optional. True, if the user is allowed to send photos
can_send_videos | Boolean | Optional. True, if the user is allowed to send videos
can_send_video_notes | Boolean | Optional. True, if the user is allowed to send video notes
can_send_voice_notes | Boolean | Optional. True, if the user is allowed to send voice notes
can_send_polls | Boolean | Optional. True, if the user is allowed to send polls and checklists
can_send_other_messages | Boolean | Optional. True, if the user is allowed to send animations, games, stickers and use inline bots
can_add_web_page_previews | Boolean | Optional. True, if the user is allowed to add web page previews to their messages
can_edit_tag | Boolean | Optional. True, if the user is allowed to edit their own tag
can_change_info | Boolean | Optional. True, if the user is allowed to change the chat title, photo and other settings. Ignored in public supergroups
can_invite_users | Boolean | Optional. True, if the user is allowed to invite new users to the chat
can_pin_messages | Boolean | Optional. True, if the user is allowed to pin messages. Ignored in public supergroups
can_manage_topics | Boolean | Optional. True, if the user is allowed to create forum topics. If omitted defaults to the value of can_pin_messages

#### Birthdate

Describes the birthdate of a user.

Field | Type | Description
--- | --- | ---
day | Integer | Day of the user's birth; 1-31
month | Integer | Month of the user's birth; 1-12
year | Integer | Optional. Year of the user's birth

#### BusinessIntro

Contains information about the start page settings of a Telegram Business account.

Field | Type | Description
--- | --- | ---
title | String | Optional. Title text of the business intro
message | String | Optional. Message text of the business intro
sticker | Sticker | Optional. Sticker of the business intro

#### BusinessLocation

Contains information about the location of a Telegram Business account.

Field | Type | Description
--- | --- | ---
address | String | Address of the business
location | Location | Optional. Location of the business

#### BusinessOpeningHoursInterval

Describes an interval of time during which a business is open.

Field | Type | Description
--- | --- | ---
opening_minute | Integer | The minute's sequence number in a week, starting on Monday, marking the start of the time interval during which the business is open; 0 - 7 * 24 * 60
closing_minute | Integer | The minute's sequence number in a week, starting on Monday, marking the end of the time interval during which the business is open; 0 - 8 * 24 * 60

#### BusinessOpeningHours

Describes the opening hours of a business.

Field | Type | Description
--- | --- | ---
time_zone_name | String | Unique name of the time zone for which the opening hours are defined
opening_hours | Array of BusinessOpeningHoursInterval | List of time intervals describing business opening hours

#### UserRating

This object describes the rating of a user based on their Telegram Star spendings.

Field | Type | Description
--- | --- | ---
level | Integer | Current level of the user, indicating their reliability when purchasing digital goods and services. A higher level suggests a more trustworthy customer; a negative level is likely reason for concern.
rating | Integer | Numerical value of the user's rating; the higher the rating, the better
current_level_rating | Integer | The rating value required to get the current level
next_level_rating | Integer | Optional. The rating value required to get to the next level; omitted if the maximum level was reached

#### StoryAreaPosition

Describes the position of a clickable area within a story.

Field | Type | Description
--- | --- | ---
x_percentage | Float | The abscissa of the area's center, as a percentage of the media width
y_percentage | Float | The ordinate of the area's center, as a percentage of the media height
width_percentage | Float | The width of the area's rectangle, as a percentage of the media width
height_percentage | Float | The height of the area's rectangle, as a percentage of the media height
rotation_angle | Float | The clockwise rotation angle of the rectangle, in degrees; 0-360
corner_radius_percentage | Float | The radius of the rectangle corner rounding, as a percentage of the media width

#### LocationAddress

Describes the physical address of a location.

Field | Type | Description
--- | --- | ---
country_code | String | The two-letter ISO 3166-1 alpha-2 country code of the country where the location is located
state | String | Optional. State of the location
city | String | Optional. City of the location
street | String | Optional. Street address of the location

#### StoryAreaType

Describes the type of a clickable area on a story. Currently, it can be one of

- StoryAreaTypeLocation
- StoryAreaTypeSuggestedReaction
- StoryAreaTypeLink
- StoryAreaTypeWeather
- StoryAreaTypeUniqueGift

#### StoryAreaTypeLocation

Describes a story area pointing to a location. Currently, a story can have up to 10 location areas.

Field | Type | Description
--- | --- | ---
type | String | Type of the area, always “location”
latitude | Float | Location latitude in degrees
longitude | Float | Location longitude in degrees
address | LocationAddress | Optional. Address of the location

#### StoryAreaTypeSuggestedReaction

Describes a story area pointing to a suggested reaction. Currently, a story can have up to 5 suggested reaction areas.

Field | Type | Description
--- | --- | ---
type | String | Type of the area, always “suggested_reaction”
reaction_type | ReactionType | Type of the reaction
is_dark | Boolean | Optional. Pass True if the reaction area has a dark background
is_flipped | Boolean | Optional. Pass True if reaction area corner is flipped

#### StoryAreaTypeLink

Describes a story area pointing to an HTTP or tg:// link. Currently, a story can have up to 3 link areas.

Field | Type | Description
--- | --- | ---
type | String | Type of the area, always “link”
url | String | HTTP or tg:// URL to be opened when the area is clicked

#### StoryAreaTypeWeather

Describes a story area containing weather information. Currently, a story can have up to 3 weather areas.

Field | Type | Description
--- | --- | ---
type | String | Type of the area, always “weather”
temperature | Float | Temperature, in degree Celsius
emoji | String | Emoji representing the weather
background_color | Integer | A color of the area background in the ARGB format

#### StoryAreaTypeUniqueGift

Describes a story area pointing to a unique gift. Currently, a story can have at most 1 unique gift area.

Field | Type | Description
--- | --- | ---
type | String | Type of the area, always “unique_gift”
name | String | Unique name of the gift

#### StoryArea

Describes a clickable area on a story media.

Field | Type | Description
--- | --- | ---
position | StoryAreaPosition | Position of the area
type | StoryAreaType | Type of the area

#### ChatLocation

Represents a location to which a chat is connected.

Field | Type | Description
--- | --- | ---
location | Location | The location to which the supergroup is connected. Can't be a live location.
address | String | Location address; 1-64 characters, as defined by the chat owner

#### ReactionType

This object describes the type of a reaction. Currently, it can be one of

- ReactionTypeEmoji
- ReactionTypeCustomEmoji
- ReactionTypePaid

#### ReactionTypeEmoji

The reaction is based on an emoji.

Field | Type | Description
--- | --- | ---
type | String | Type of the reaction, always “emoji”
emoji | String | Reaction emoji. Currently, it can be one of "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", "", ""

#### ReactionTypeCustomEmoji

The reaction is based on a custom emoji.

Field | Type | Description
--- | --- | ---
type | String | Type of the reaction, always “custom_emoji”
custom_emoji_id | String | Custom emoji identifier

#### ReactionTypePaid

The reaction is paid.

Field | Type | Description
--- | --- | ---
type | String | Type of the reaction, always “paid”

#### ReactionCount

Represents a reaction added to a message along with the number of times it was added.

Field | Type | Description
--- | --- | ---
type | ReactionType | Type of the reaction
total_count | Integer | Number of times the reaction was added

#### MessageReactionUpdated

This object represents a change of a reaction on a message performed by a user.

Field | Type | Description
--- | --- | ---
chat | Chat | The chat containing the message the user reacted to
message_id | Integer | Unique identifier of the message inside the chat
user | User | Optional. The user that changed the reaction, if the user isn't anonymous
actor_chat | Chat | Optional. The chat on behalf of which the reaction was changed, if the user is anonymous
date | Integer | Date of the change in Unix time
old_reaction | Array of ReactionType | Previous list of reaction types that were set by the user
new_reaction | Array of ReactionType | New list of reaction types that have been set by the user

#### MessageReactionCountUpdated

This object represents reaction changes on a message with anonymous reactions.

Field | Type | Description
--- | --- | ---
chat | Chat | The chat containing the message
message_id | Integer | Unique message identifier inside the chat
date | Integer | Date of the change in Unix time
reactions | Array of ReactionCount | List of reactions that are present on the message

#### ForumTopic

This object represents a forum topic.

Field | Type | Description
--- | --- | ---
message_thread_id | Integer | Unique identifier of the forum topic
name | String | Name of the topic
icon_color | Integer | Color of the topic icon in RGB format
icon_custom_emoji_id | String | Optional. Unique identifier of the custom emoji shown as the topic icon
is_name_implicit | True | Optional. True, if the name of the topic wasn't specified explicitly by its creator and likely needs to be changed by the bot

#### GiftBackground

This object describes the background of a gift.

Field | Type | Description
--- | --- | ---
center_color | Integer | Center color of the background in RGB format
edge_color | Integer | Edge color of the background in RGB format
text_color | Integer | Text color of the background in RGB format

#### Gift

This object represents a gift that can be sent by the bot.

Field | Type | Description
--- | --- | ---
id | String | Unique identifier of the gift
sticker | Sticker | The sticker that represents the gift
star_count | Integer | The number of Telegram Stars that must be paid to send the sticker
upgrade_star_count | Integer | Optional. The number of Telegram Stars that must be paid to upgrade the gift to a unique one
is_premium | True | Optional. True, if the gift can only be purchased by Telegram Premium subscribers
has_colors | True | Optional. True, if the gift can be used (after being upgraded) to customize a user's appearance
total_count | Integer | Optional. The total number of gifts of this type that can be sent by all users; for limited gifts only
remaining_count | Integer | Optional. The number of remaining gifts of this type that can be sent by all users; for limited gifts only
personal_total_count | Integer | Optional. The total number of gifts of this type that can be sent by the bot; for limited gifts only
personal_remaining_count | Integer | Optional. The number of remaining gifts of this type that can be sent by the bot; for limited gifts only
background | GiftBackground | Optional. Background of the gift
unique_gift_variant_count | Integer | Optional. The total number of different unique gifts that can be obtained by upgrading the gift
publisher_chat | Chat | Optional. Information about the chat that published the gift

#### Gifts

This object represent a list of gifts.

Field | Type | Description
--- | --- | ---
gifts | Array of Gift | The list of gifts

#### UniqueGiftModel

This object describes the model of a unique gift.

Field | Type | Description
--- | --- | ---
name | String | Name of the model
sticker | Sticker | The sticker that represents the unique gift
rarity_per_mille | Integer | The number of unique gifts that receive this model for every 1000 gift upgrades. Always 0 for crafted gifts.
rarity | String | Optional. Rarity of the model if it is a crafted model. Currently, can be “uncommon”, “rare”, “epic”, or “legendary”.

#### UniqueGiftSymbol

This object describes the symbol shown on the pattern of a unique gift.

Field | Type | Description
--- | --- | ---
name | String | Name of the symbol
sticker | Sticker | The sticker that represents the unique gift
rarity_per_mille | Integer | The number of unique gifts that receive this model for every 1000 gifts upgraded

#### UniqueGiftBackdropColors

This object describes the colors of the backdrop of a unique gift.

Field | Type | Description
--- | --- | ---
center_color | Integer | The color in the center of the backdrop in RGB format
edge_color | Integer | The color on the edges of the backdrop in RGB format
symbol_color | Integer | The color to be applied to the symbol in RGB format
text_color | Integer | The color for the text on the backdrop in RGB format

#### UniqueGiftBackdrop

This object describes the backdrop of a unique gift.

Field | Type | Description
--- | --- | ---
name | String | Name of the backdrop
colors | UniqueGiftBackdropColors | Colors of the backdrop
rarity_per_mille | Integer | The number of unique gifts that receive this backdrop for every 1000 gifts upgraded

#### UniqueGiftColors

This object contains information about the color scheme for a user's name, message replies and link previews based on a unique gift.

Field | Type | Description
--- | --- | ---
model_custom_emoji_id | String | Custom emoji identifier of the unique gift's model
symbol_custom_emoji_id | String | Custom emoji identifier of the unique gift's symbol
light_theme_main_color | Integer | Main color used in light themes; RGB format
light_theme_other_colors | Array of Integer | List of 1-3 additional colors used in light themes; RGB format
dark_theme_main_color | Integer | Main color used in dark themes; RGB format
dark_theme_other_colors | Array of Integer | List of 1-3 additional colors used in dark themes; RGB format

#### UniqueGift

This object describes a unique gift that was upgraded from a regular gift.

Field | Type | Description
--- | --- | ---
gift_id | String | Identifier of the regular gift from which the gift was upgraded
base_name | String | Human-readable name of the regular gift from which this unique gift was upgraded
name | String | Unique name of the gift. This name can be used in `https://t.me/nft/...` links and story areas
number | Integer | Unique number of the upgraded gift among gifts upgraded from the same regular gift
model | UniqueGiftModel | Model of the gift
symbol | UniqueGiftSymbol | Symbol of the gift
backdrop | UniqueGiftBackdrop | Backdrop of the gift
is_premium | True | Optional. True, if the original regular gift was exclusively purchaseable by Telegram Premium subscribers
is_burned | True | Optional. True, if the gift was used to craft another gift and isn't available anymore
is_from_blockchain | True | Optional. True, if the gift is assigned from the TON blockchain and can't be resold or transferred in Telegram
colors | UniqueGiftColors | Optional. The color scheme that can be used by the gift's owner for the chat's name, replies to messages and link previews; for business account gifts and gifts that are currently on sale only
publisher_chat | Chat | Optional. Information about the chat that published the gift

#### GiftInfo

Describes a service message about a regular gift that was sent or received.

Field | Type | Description
--- | --- | ---
gift | Gift | Information about the gift
owned_gift_id | String | Optional. Unique identifier of the received gift for the bot; only present for gifts received on behalf of business accounts
convert_star_count | Integer | Optional. Number of Telegram Stars that can be claimed by the receiver by converting the gift; omitted if conversion to Telegram Stars is impossible
prepaid_upgrade_star_count | Integer | Optional. Number of Telegram Stars that were prepaid for the ability to upgrade the gift
is_upgrade_separate | True | Optional. True, if the gift's upgrade was purchased after the gift was sent
can_be_upgraded | True | Optional. True, if the gift can be upgraded to a unique gift
text | String | Optional. Text of the message that was added to the gift
entities | Array of MessageEntity | Optional. Special entities that appear in the text
is_private | True | Optional. True, if the sender and gift text are shown only to the gift receiver; otherwise, everyone will be able to see them
unique_gift_number | Integer | Optional. Unique number reserved for this gift when upgraded. See the number field in UniqueGift

#### UniqueGiftInfo

Describes a service message about a unique gift that was sent or received.

Field | Type | Description
--- | --- | ---
gift | UniqueGift | Information about the gift
origin | String | Origin of the gift. Currently, either “upgrade” for gifts upgraded from regular gifts, “transfer” for gifts transferred from other users or channels, “resale” for gifts bought from other users, “gifted_upgrade” for upgrades purchased after the gift was sent, or “offer” for gifts bought or sold through gift purchase offers
last_resale_currency | String | Optional. For gifts bought from other users, the currency in which the payment for the gift was done. Currently, one of “XTR” for Telegram Stars or “TON” for toncoins.
last_resale_amount | Integer | Optional. For gifts bought from other users, the price paid for the gift in either Telegram Stars or nanotoncoins
owned_gift_id | String | Optional. Unique identifier of the received gift for the bot; only present for gifts received on behalf of business accounts
transfer_star_count | Integer | Optional. Number of Telegram Stars that must be paid to transfer the gift; omitted if the bot cannot transfer the gift
next_transfer_date | Integer | Optional. Point in time (Unix timestamp) when the gift can be transferred. If it is in the past, then the gift can be transferred now

#### OwnedGift

This object describes a gift received and owned by a user or a chat. Currently, it can be one of

- OwnedGiftRegular
- OwnedGiftUnique

#### OwnedGiftRegular

Describes a regular gift owned by a user or a chat.

Field | Type | Description
--- | --- | ---
type | String | Type of the gift, always “regular”
gift | Gift | Information about the regular gift
owned_gift_id | String | Optional. Unique identifier of the gift for the bot; for gifts received on behalf of business accounts only
sender_user | User | Optional. Sender of the gift if it is a known user
send_date | Integer | Date the gift was sent in Unix time
text | String | Optional. Text of the message that was added to the gift
entities | Array of MessageEntity | Optional. Special entities that appear in the text
is_private | True | Optional. True, if the sender and gift text are shown only to the gift receiver; otherwise, everyone will be able to see them
is_saved | True | Optional. True, if the gift is displayed on the account's profile page; for gifts received on behalf of business accounts only
can_be_upgraded | True | Optional. True, if the gift can be upgraded to a unique gift; for gifts received on behalf of business accounts only
was_refunded | True | Optional. True, if the gift was refunded and isn't available anymore
convert_star_count | Integer | Optional. Number of Telegram Stars that can be claimed by the receiver instead of the gift; omitted if the gift cannot be converted to Telegram Stars; for gifts received on behalf of business accounts only
prepaid_upgrade_star_count | Integer | Optional. Number of Telegram Stars that were paid for the ability to upgrade the gift
is_upgrade_separate | True | Optional. True, if the gift's upgrade was purchased after the gift was sent; for gifts received on behalf of business accounts only
unique_gift_number | Integer | Optional. Unique number reserved for this gift when upgraded. See the number field in UniqueGift

#### OwnedGiftUnique

Describes a unique gift received and owned by a user or a chat.

Field | Type | Description
--- | --- | ---
type | String | Type of the gift, always “unique”
gift | UniqueGift | Information about the unique gift
owned_gift_id | String | Optional. Unique identifier of the received gift for the bot; for gifts received on behalf of business accounts only
sender_user | User | Optional. Sender of the gift if it is a known user
send_date | Integer | Date the gift was sent in Unix time
is_saved | True | Optional. True, if the gift is displayed on the account's profile page; for gifts received on behalf of business accounts only
can_be_transferred | True | Optional. True, if the gift can be transferred to another owner; for gifts received on behalf of business accounts only
transfer_star_count | Integer | Optional. Number of Telegram Stars that must be paid to transfer the gift; omitted if the bot cannot transfer the gift
next_transfer_date | Integer | Optional. Point in time (Unix timestamp) when the gift can be transferred. If it is in the past, then the gift can be transferred now

#### OwnedGifts

Contains the list of gifts received and owned by a user or a chat.

Field | Type | Description
--- | --- | ---
total_count | Integer | The total number of gifts owned by the user or the chat
gifts | Array of OwnedGift | The list of gifts
next_offset | String | Optional. Offset for the next request. If empty, then there are no more results

#### AcceptedGiftTypes

This object describes the types of gifts that can be gifted to a user or a chat.

Field | Type | Description
--- | --- | ---
unlimited_gifts | Boolean | True, if unlimited regular gifts are accepted
limited_gifts | Boolean | True, if limited regular gifts are accepted
unique_gifts | Boolean | True, if unique gifts or gifts that can be upgraded to unique for free are accepted
premium_subscription | Boolean | True, if a Telegram Premium subscription is accepted
gifts_from_channels | Boolean | True, if transfers of unique gifts from channels are accepted

#### StarAmount

Describes an amount of Telegram Stars.

Field | Type | Description
--- | --- | ---
amount | Integer | Integer amount of Telegram Stars, rounded to 0; can be negative
nanostar_amount | Integer | Optional. The number of 1/1000000000 shares of Telegram Stars; from -999999999 to 999999999; can be negative if and only if amount is non-positive

#### BotCommand

This object represents a bot command.

Field | Type | Description
--- | --- | ---
command | String | Text of the command; 1-32 characters. Can contain only lowercase English letters, digits and underscores.
description | String | Description of the command; 1-256 characters.

#### BotCommandScope

This object represents the scope to which bot commands are applied. Currently, the following 7 scopes are supported:

- BotCommandScopeDefault
- BotCommandScopeAllPrivateChats
- BotCommandScopeAllGroupChats
- BotCommandScopeAllChatAdministrators
- BotCommandScopeChat
- BotCommandScopeChatAdministrators
- BotCommandScopeChatMember

#### Determining list of commands

The following algorithm is used to determine the list of commands for a particular user viewing the bot menu. The first list of commands which is set is returned:

Commands in the chat with the bot

- botCommandScopeChat + language_code
- botCommandScopeChat
- botCommandScopeAllPrivateChats + language_code
- botCommandScopeAllPrivateChats
- botCommandScopeDefault + language_code
- botCommandScopeDefault

Commands in group and supergroup chats

- botCommandScopeChatMember + language_code
- botCommandScopeChatMember
- botCommandScopeChatAdministrators + language_code (administrators only)
- botCommandScopeChatAdministrators (administrators only)
- botCommandScopeChat + language_code
- botCommandScopeChat
- botCommandScopeAllChatAdministrators + language_code (administrators only)
- botCommandScopeAllChatAdministrators (administrators only)
- botCommandScopeAllGroupChats + language_code
- botCommandScopeAllGroupChats
- botCommandScopeDefault + language_code
- botCommandScopeDefault

#### BotCommandScopeDefault

Represents the default scope of bot commands. Default commands are used if no commands with a narrower scope are specified for the user.

Field | Type | Description
--- | --- | ---
type | String | Scope type, must be default

#### BotCommandScopeAllPrivateChats

Represents the scope of bot commands, covering all private chats.

Field | Type | Description
--- | --- | ---
type | String | Scope type, must be all_private_chats

#### BotCommandScopeAllGroupChats

Represents the scope of bot commands, covering all group and supergroup chats.

Field | Type | Description
--- | --- | ---
type | String | Scope type, must be all_group_chats

#### BotCommandScopeAllChatAdministrators

Represents the scope of bot commands, covering all group and supergroup chat administrators.

Field | Type | Description
--- | --- | ---
type | String | Scope type, must be all_chat_administrators

#### BotCommandScopeChat

Represents the scope of bot commands, covering a specific chat.

Field | Type | Description
--- | --- | ---
type | String | Scope type, must be chat
chat_id | Integer or String | Unique identifier for the target chat or username of the target supergroup (in the format `@supergroupusername`). Channel direct messages chats and channel chats aren't supported.

#### BotCommandScopeChatAdministrators

Represents the scope of bot commands, covering all administrators of a specific group or supergroup chat.

Field | Type | Description
--- | --- | ---
type | String | Scope type, must be chat_administrators
chat_id | Integer or String | Unique identifier for the target chat or username of the target supergroup (in the format `@supergroupusername`). Channel direct messages chats and channel chats aren't supported.

#### BotCommandScopeChatMember

Represents the scope of bot commands, covering a specific member of a group or supergroup chat.

Field | Type | Description
--- | --- | ---
type | String | Scope type, must be chat_member
chat_id | Integer or String | Unique identifier for the target chat or username of the target supergroup (in the format `@supergroupusername`). Channel direct messages chats and channel chats aren't supported.
user_id | Integer | Unique identifier of the target user

#### BotName

This object represents the bot's name.

Field | Type | Description
--- | --- | ---
name | String | The bot's name

#### BotDescription

This object represents the bot's description.

Field | Type | Description
--- | --- | ---
description | String | The bot's description

#### BotShortDescription

This object represents the bot's short description.

Field | Type | Description
--- | --- | ---
short_description | String | The bot's short description

#### MenuButton

This object describes the bot's menu button in a private chat. It should be one of

- MenuButtonCommands
- MenuButtonWebApp
- MenuButtonDefault

If a menu button other than MenuButtonDefault is set for a private chat, then it is applied in the chat. Otherwise the default menu button is applied. By default, the menu button opens the list of bot commands.

#### MenuButtonCommands

Represents a menu button, which opens the bot's list of commands.

Field | Type | Description
--- | --- | ---
type | String | Type of the button, must be commands

#### MenuButtonWebApp

Represents a menu button, which launches a Web App.

Field | Type | Description
--- | --- | ---
type | String | Type of the button, must be web_app
text | String | Text on the button
web_app | WebAppInfo | Description of the Web App that will be launched when the user presses the button. The Web App will be able to send an arbitrary message on behalf of the user using the method answerWebAppQuery. Alternatively, a `t.me` link to a Web App of the bot can be specified in the object instead of the Web App's URL, in which case the Web App will be opened as if the user pressed the link.

#### MenuButtonDefault

Describes that no specific value for the menu button was set.

Field | Type | Description
--- | --- | ---
type | String | Type of the button, must be default

#### ChatBoostSource

This object describes the source of a chat boost. It can be one of

- ChatBoostSourcePremium
- ChatBoostSourceGiftCode
- ChatBoostSourceGiveaway

#### ChatBoostSourcePremium

The boost was obtained by subscribing to Telegram Premium or by gifting a Telegram Premium subscription to another user.

Field | Type | Description
--- | --- | ---
source | String | Source of the boost, always “premium”
user | User | User that boosted the chat

#### ChatBoostSourceGiftCode

The boost was obtained by the creation of Telegram Premium gift codes to boost a chat. Each such code boosts the chat 4 times for the duration of the corresponding Telegram Premium subscription.

Field | Type | Description
--- | --- | ---
source | String | Source of the boost, always “gift_code”
user | User | User for which the gift code was created

#### ChatBoostSourceGiveaway

The boost was obtained by the creation of a Telegram Premium or a Telegram Star giveaway. This boosts the chat 4 times for the duration of the corresponding Telegram Premium subscription for Telegram Premium giveaways and prize_star_count / 500 times for one year for Telegram Star giveaways.

Field | Type | Description
--- | --- | ---
source | String | Source of the boost, always “giveaway”
giveaway_message_id | Integer | Identifier of a message in the chat with the giveaway; the message could have been deleted already. May be 0 if the message isn't sent yet.
user | User | Optional. User that won the prize in the giveaway if any; for Telegram Premium giveaways only
prize_star_count | Integer | Optional. The number of Telegram Stars to be split between giveaway winners; for Telegram Star giveaways only
is_unclaimed | True | Optional. True, if the giveaway was completed, but there was no user to win the prize

#### ChatBoost

This object contains information about a chat boost.

Field | Type | Description
--- | --- | ---
boost_id | String | Unique identifier of the boost
add_date | Integer | Point in time (Unix timestamp) when the chat was boosted
expiration_date | Integer | Point in time (Unix timestamp) when the boost will automatically expire, unless the booster's Telegram Premium subscription is prolonged
source | ChatBoostSource | Source of the added boost

#### ChatBoostUpdated

This object represents a boost added to a chat or changed.

Field | Type | Description
--- | --- | ---
chat | Chat | Chat which was boosted
boost | ChatBoost | Information about the chat boost

#### ChatBoostRemoved

This object represents a boost removed from a chat.

Field | Type | Description
--- | --- | ---
chat | Chat | Chat which was boosted
boost_id | String | Unique identifier of the boost
remove_date | Integer | Point in time (Unix timestamp) when the boost was removed
source | ChatBoostSource | Source of the removed boost

#### ChatOwnerLeft

Describes a service message about the chat owner leaving the chat.

Field | Type | Description
--- | --- | ---
new_owner | User | Optional. The user which will be the new owner of the chat if the previous owner does not return to the chat

#### ChatOwnerChanged

Describes a service message about an ownership change in the chat.

Field | Type | Description
--- | --- | ---
new_owner | User | The new owner of the chat

#### UserChatBoosts

This object represents a list of boosts added to a chat by a user.

Field | Type | Description
--- | --- | ---
boosts | Array of ChatBoost | The list of boosts added to the chat by the user

#### BusinessBotRights

Represents the rights of a business bot.

Field | Type | Description
--- | --- | ---
can_reply | True | Optional. True, if the bot can send and edit messages in the private chats that had incoming messages in the last 24 hours
can_read_messages | True | Optional. True, if the bot can mark incoming private messages as read
can_delete_sent_messages | True | Optional. True, if the bot can delete messages sent by the bot
can_delete_all_messages | True | Optional. True, if the bot can delete all private messages in managed chats
can_edit_name | True | Optional. True, if the bot can edit the first and last name of the business account
can_edit_bio | True | Optional. True, if the bot can edit the bio of the business account
can_edit_profile_photo | True | Optional. True, if the bot can edit the profile photo of the business account
can_edit_username | True | Optional. True, if the bot can edit the username of the business account
can_change_gift_settings | True | Optional. True, if the bot can change the privacy settings pertaining to gifts for the business account
can_view_gifts_and_stars | True | Optional. True, if the bot can view gifts and the amount of Telegram Stars owned by the business account
can_convert_gifts_to_stars | True | Optional. True, if the bot can convert regular gifts owned by the business account to Telegram Stars
can_transfer_and_upgrade_gifts | True | Optional. True, if the bot can transfer and upgrade gifts owned by the business account
can_transfer_stars | True | Optional. True, if the bot can transfer Telegram Stars received by the business account to its own account, or use them to upgrade and transfer gifts
can_manage_stories | True | Optional. True, if the bot can post, edit and delete stories on behalf of the business account

#### BusinessConnection

Describes the connection of the bot with a business account.

Field | Type | Description
--- | --- | ---
id | String | Unique identifier of the business connection
user | User | Business account user that created the business connection
user_chat_id | Integer | Identifier of a private chat with the user who created the business connection. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier.
date | Integer | Date the connection was established in Unix time
rights | BusinessBotRights | Optional. Rights of the business bot
is_enabled | Boolean | True, if the connection is active

#### BusinessMessagesDeleted

This object is received when messages are deleted from a connected business account.

Field | Type | Description
--- | --- | ---
business_connection_id | String | Unique identifier of the business connection
chat | Chat | Information about a chat in the business account. The bot may not have access to the chat or the corresponding user.
message_ids | Array of Integer | The list of identifiers of deleted messages in the chat of the business account

#### ResponseParameters

Describes why a request was unsuccessful.

Field | Type | Description
--- | --- | ---
migrate_to_chat_id | Integer | Optional. The group has been migrated to a supergroup with the specified identifier. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a signed 64-bit integer or double-precision float type are safe for storing this identifier.
retry_after | Integer | Optional. In case of exceeding flood control, the number of seconds left to wait before the request can be repeated

#### InputMedia

This object represents the content of a media message to be sent. It should be one of

- InputMediaAnimation
- InputMediaDocument
- InputMediaAudio
- InputMediaPhoto
- InputMediaVideo

#### InputMediaPhoto

Represents a photo to be sent.

Field | Type | Description
--- | --- | ---
type | String | Type of the result, must be photo
media | String | File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
caption | String | Optional. Caption of the photo to be sent, 0-1024 characters after entities parsing
parse_mode | String | Optional. Mode for parsing entities in the photo caption. See formatting options for more details.
caption_entities | Array of MessageEntity | Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
show_caption_above_media | Boolean | Optional. Pass True, if the caption must be shown above the message media
has_spoiler | Boolean | Optional. Pass True if the photo needs to be covered with a spoiler animation

#### InputMediaVideo

Represents a video to be sent.

Field | Type | Description
--- | --- | ---
type | String | Type of the result, must be video
media | String | File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
thumbnail | String | Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
cover | String | Optional. Cover for the video in the message. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
start_timestamp | Integer | Optional. Start timestamp for the video in the message
caption | String | Optional. Caption of the video to be sent, 0-1024 characters after entities parsing
parse_mode | String | Optional. Mode for parsing entities in the video caption. See formatting options for more details.
caption_entities | Array of MessageEntity | Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
show_caption_above_media | Boolean | Optional. Pass True, if the caption must be shown above the message media
width | Integer | Optional. Video width
height | Integer | Optional. Video height
duration | Integer | Optional. Video duration in seconds
supports_streaming | Boolean | Optional. Pass True if the uploaded video is suitable for streaming
has_spoiler | Boolean | Optional. Pass True if the video needs to be covered with a spoiler animation

#### InputMediaAnimation

Represents an animation file (GIF or H.264/MPEG-4 AVC video without sound) to be sent.

Field | Type | Description
--- | --- | ---
type | String | Type of the result, must be animation
media | String | File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
thumbnail | String | Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
caption | String | Optional. Caption of the animation to be sent, 0-1024 characters after entities parsing
parse_mode | String | Optional. Mode for parsing entities in the animation caption. See formatting options for more details.
caption_entities | Array of MessageEntity | Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
show_caption_above_media | Boolean | Optional. Pass True, if the caption must be shown above the message media
width | Integer | Optional. Animation width
height | Integer | Optional. Animation height
duration | Integer | Optional. Animation duration in seconds
has_spoiler | Boolean | Optional. Pass True if the animation needs to be covered with a spoiler animation

#### InputMediaAudio

Represents an audio file to be treated as music to be sent.

Field | Type | Description
--- | --- | ---
type | String | Type of the result, must be audio
media | String | File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
thumbnail | String | Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
caption | String | Optional. Caption of the audio to be sent, 0-1024 characters after entities parsing
parse_mode | String | Optional. Mode for parsing entities in the audio caption. See formatting options for more details.
caption_entities | Array of MessageEntity | Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
duration | Integer | Optional. Duration of the audio in seconds
performer | String | Optional. Performer of the audio
title | String | Optional. Title of the audio

#### InputMediaDocument

Represents a general file to be sent.

Field | Type | Description
--- | --- | ---
type | String | Type of the result, must be document
media | String | File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
thumbnail | String | Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
caption | String | Optional. Caption of the document to be sent, 0-1024 characters after entities parsing
parse_mode | String | Optional. Mode for parsing entities in the document caption. See formatting options for more details.
caption_entities | Array of MessageEntity | Optional. List of special entities that appear in the caption, which can be specified instead of parse_mode
disable_content_type_detection | Boolean | Optional. Disables automatic server-side content type detection for files uploaded using multipart/form-data. Always True, if the document is sent as part of an album.

#### InputFile

This object represents the contents of a file to be uploaded. Must be posted using multipart/form-data in the usual way that files are uploaded via the browser.

#### InputPaidMedia

This object describes the paid media to be sent. Currently, it can be one of

- InputPaidMediaPhoto
- InputPaidMediaVideo

#### InputPaidMediaPhoto

The paid media to send is a photo.

Field | Type | Description
--- | --- | ---
type | String | Type of the media, must be photo
media | String | File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »

#### InputPaidMediaVideo

The paid media to send is a video.

Field | Type | Description
--- | --- | ---
type | String | Type of the media, must be video
media | String | File to send. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
thumbnail | String | Optional. Thumbnail of the file sent; can be ignored if thumbnail generation for the file is supported server-side. The thumbnail should be in JPEG format and less than 200 kB in size. A thumbnail's width and height should not exceed 320. Ignored if the file is not uploaded using multipart/form-data. Thumbnails can't be reused and can be only uploaded as a new file, so you can pass “attach://<file_attach_name>” if the thumbnail was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
cover | String | Optional. Cover for the video in the message. Pass a file_id to send a file that exists on the Telegram servers (recommended), pass an HTTP URL for Telegram to get a file from the Internet, or pass “attach://<file_attach_name>” to upload a new one using multipart/form-data under <file_attach_name> name. More information on Sending Files »
start_timestamp | Integer | Optional. Start timestamp for the video in the message
width | Integer | Optional. Video width
height | Integer | Optional. Video height
duration | Integer | Optional. Video duration in seconds
supports_streaming | Boolean | Optional. Pass True if the uploaded video is suitable for streaming

#### InputProfilePhoto

This object describes a profile photo to set. Currently, it can be one of

- InputProfilePhotoStatic
- InputProfilePhotoAnimated

#### InputProfilePhotoStatic

A static profile photo in the .JPG format.

Field | Type | Description
--- | --- | ---
type | String | Type of the profile photo, must be static
photo | String | The static profile photo. Profile photos can't be reused and can only be uploaded as a new file, so you can pass “attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »

#### InputProfilePhotoAnimated

An animated profile photo in the MPEG4 format.

Field | Type | Description
--- | --- | ---
type | String | Type of the profile photo, must be animated
animation | String | The animated profile photo. Profile photos can't be reused and can only be uploaded as a new file, so you can pass “attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
main_frame_timestamp | Float | Optional. Timestamp in seconds of the frame that will be used as the static profile photo. Defaults to 0.0.

#### InputStoryContent

This object describes the content of a story to post. Currently, it can be one of

- InputStoryContentPhoto
- InputStoryContentVideo

#### InputStoryContentPhoto

Describes a photo to post as a story.

Field | Type | Description
--- | --- | ---
type | String | Type of the content, must be photo
photo | String | The photo to post as a story. The photo must be of the size 1080x1920 and must not exceed 10 MB. The photo can't be reused and can only be uploaded as a new file, so you can pass “attach://<file_attach_name>” if the photo was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »

#### InputStoryContentVideo

Describes a video to post as a story.

Field | Type | Description
--- | --- | ---
type | String | Type of the content, must be video
video | String | The video to post as a story. The video must be of the size 720x1280, streamable, encoded with H.265 codec, with key frames added each second in the MPEG4 format, and must not exceed 30 MB. The video can't be reused and can only be uploaded as a new file, so you can pass “attach://<file_attach_name>” if the video was uploaded using multipart/form-data under <file_attach_name>. More information on Sending Files »
duration | Float | Optional. Precise duration of the video in seconds; 0-60
cover_frame_timestamp | Float | Optional. Timestamp in seconds of the frame that will be used as the static cover for the story. Defaults to 0.0.
is_animation | Boolean | Optional. Pass True if the video has no sound

#### Sending files

There are three ways to send files (photos, stickers, audio, media, etc.):

1. If the file is already stored somewhere on the Telegram servers, you don't need to reupload it: each file object has a file_id field, simply pass this file_id as a parameter instead of uploading. There are no limits for files sent this way.
2. Provide Telegram with an HTTP URL for the file to be sent. Telegram will download and send the file. 5 MB max size for photos and 20 MB max for other types of content.
3. Post the file using multipart/form-data in the usual way that files are uploaded via the browser. 10 MB max size for photos, 50 MB for other files.

Sending by file_id

- It is not possible to change the file type when resending by file_id. I.e. a video can't be sent as a photo, a photo can't be sent as a document, etc.
- It is not possible to resend thumbnails.
- Resending a photo by file_id will send all of its sizes.
- file_id is unique for each individual bot and can't be transferred from one bot to another.
- file_id uniquely identifies a file, but a file can have different valid file_ids even for the same bot.

Sending by URL

- When sending by URL the target file must have the correct MIME type (e.g., audio/mpeg for sendAudio, etc.).
- In sendDocument, sending by URL will currently only work for .PDF and .ZIP files.
- To use sendVoice, the file must have the type audio/ogg and be no more than 1MB in size. 1-20MB voice notes will be sent as files.
- Other configurations may work but we can't guarantee that they will.

#### Accent colors

Colors with identifiers 0 (red), 1 (orange), 2 (purple/violet), 3 (green), 4 (cyan), 5 (blue), 6 (pink) can be customized by app themes. Additionally, the following colors in RGB format are currently in use.

Color identifier | Light colors | Dark colors
--- | --- | ---
7 | E15052 F9AE63 | FF9380 992F37
8 | E0802B FAC534 | ECB04E C35714
9 | A05FF3 F48FFF | C697FF 5E31C8
10 | 27A910 A7DC57 | A7EB6E 167E2D
11 | 27ACCE 82E8D6 | 40D8D0 045C7F
12 | 3391D4 7DD3F0 | 52BFFF 0B5494
13 | DD4371 FFBE9F | FF86A6 8E366E
14 | 247BED F04856 FFFFFF | 3FA2FE E5424F FFFFFF
15 | D67722 1EA011 FFFFFF | FF905E 32A527 FFFFFF
16 | 179E42 E84A3F FFFFFF | 66D364 D5444F FFFFFF
17 | 2894AF 6FC456 FFFFFF | 22BCE2 3DA240 FFFFFF
18 | 0C9AB3 FFAD95 FFE6B5 | 22BCE2 FF9778 FFDA6B
19 | 7757D6 F79610 FFDE8E | 9791FF F2731D FFDB59
20 | 1585CF F2AB1D FFFFFF | 3DA6EB EEA51D FFFFFF

#### Profile accent colors

Currently, the following colors in RGB format are in use for profile backgrounds.

Color identifier | Light colors | Dark colors
--- | --- | ---
0 | BA5650 | 9C4540
1 | C27C3E | 945E2C
2 | 956AC8 | 715099
3 | 49A355 | 33713B
4 | 3E97AD | 387E87
5 | 5A8FBB | 477194
6 | B85378 | 944763
7 | 7F8B95 | 435261
8 | C9565D D97C57 | 994343 AC583E
9 | CF7244 CC9433 | 8F552F A17232
10 | 9662D4 B966B6 | 634691 9250A2
11 | 3D9755 89A650 | 296A43 5F8F44
12 | 3D95BA 50AD98 | 306C7C 3E987E
13 | 538BC2 4DA8BD | 38618C 458BA1
14 | B04F74 D1666D | 884160 A65259
15 | 637482 7B8A97 | 53606E 384654

#### Inline mode objects

Objects and methods used in the inline mode are described in the Inline mode section.